@@ -20,6 +20,8 @@
 
 #include "control/controlid.h"
 
+#include "history/historymanager.h"
+
 #include "command.h"
 #include "global.h"
 #include "httpcode.h"
@@ -77,7 +79,9 @@ ArticleViewMain::~ArticleViewMain()
     if( seen >= 1 ) get_article()->set_number_seen( seen );
 
     // 閉じたタブ履歴更新
-    CORE::core_set_command( "set_history_close", url_article() );
+    HISTORY::append_history( URL_HISTCLOSEVIEW,
+                             DBTREE::url_dat( get_url() ),
+                             DBTREE::article_subject( get_url() ), TYPE_THREAD );
 
     if( get_live() ) live_stop();
 }
@@ -132,13 +136,12 @@ const bool ArticleViewMain::is_loading()
 // 更新した
 const bool ArticleViewMain::is_updated()
 {
-    int code = DBTREE::article_code( url_article() );
 
 #ifdef _DEBUG
-    std::cout << "ArticleViewMain::is_updated " << code << " / " << ( code == HTTP_OK || code == HTTP_PARTIAL_CONTENT ) << std::endl;
+    std::cout << "ArticleViewMain::is_updated " << url_article() << " " << ( get_article()->get_status() & STATUS_UPDATED ) << std::endl;
 #endif
 
-    return ( code == HTTP_OK || code == HTTP_PARTIAL_CONTENT );
+    return ( get_article()->get_status() & STATUS_UPDATED );
 }
 
 
@@ -146,7 +149,7 @@ const bool ArticleViewMain::is_updated()
 const bool ArticleViewMain::is_check_update()
 {
 #ifdef _DEBUG
-    std::cout << "ArticleViewMain::is_check_update " << ( get_article()->get_status() & STATUS_UPDATE ) << std::endl;
+    std::cout << "ArticleViewMain::is_check_update " << url_article() << " " << ( get_article()->get_status() & STATUS_UPDATE ) << std::endl;
 #endif
 
     return ( get_article()->get_status() & STATUS_UPDATE );
@@ -184,13 +187,7 @@ void ArticleViewMain::exec_reload()
         return;
     }
 
-    // オートリロードのカウンタを0にする
-    View::reset_autoreload_counter();
-
     show_view();
-
-    // スレ履歴更新
-    CORE::core_set_command( "set_history_article", url_article() );
 }
 
 
@@ -200,10 +197,17 @@ void ArticleViewMain::exec_reload()
 //
 void ArticleViewMain::show_view()
 {
+    if( is_loading() ) return;
+
     m_gotonum_reserve = 0;
     m_gotonum_seen = 0;
+    m_set_history = false;
     m_show_instdialog = false;
     m_playsound = false;
+    m_show_closedialog = false;
+
+    // オートリロードのカウンタを0にする
+    reset_autoreload_counter();
 
 #ifdef _DEBUG
     std::cout << "ArticleViewMain::show_view\n";
@@ -230,11 +234,11 @@ void ArticleViewMain::show_view()
     //   キャッシュを読み込んでいる場合    -> show_viewから直接  update_finish を呼ぶ
     //  　　　　　　　　　　　　　　　　　　　　ロード終了時にもupdate_finish がコールバックされる
 
-    bool call_update_finish = get_article()->is_cache_read();
+    const bool call_update_finish = get_article()->is_cache_read();
 
     // キャッシュに含まれているレスを表示
-    int from_num = drawarea()->max_number() + 1;
-    int to_num = get_article()->get_number_load();
+    const int from_num = drawarea()->max_number() + 1;
+    const int to_num = get_article()->get_number_load();
     if( from_num <= to_num ){
 
         drawarea()->append_res( from_num, to_num );
@@ -263,6 +267,8 @@ void ArticleViewMain::show_view()
         const bool live = get_live();
         set_live( false );
 
+        if( ! SESSION::is_online() ) m_set_history = true;
+
         update_finish();
 
         CONFIG::set_jump_after_reload( jump_bottom );
@@ -276,6 +282,7 @@ void ArticleViewMain::show_view()
         if( ! SESSION::is_online() ) update_finish();
     }
 
+    m_set_history = true;
 
     // オフラインならダウンロードを開始しない
     if( ! SESSION::is_online() ) return;
@@ -285,6 +292,8 @@ void ArticleViewMain::show_view()
         m_show_instdialog = true;
     }
 
+    m_show_closedialog = true;
+
     clear_highlight();
     if( ! get_live() && SESSION::is_online() ) m_playsound = true;
 
@@ -459,7 +468,20 @@ void ArticleViewMain::update_finish()
         drawarea()->update_live_speed( get_autoreload_sec() );
     }
 
+    // 履歴に登録
+    if( m_set_history ) HISTORY::append_history( URL_HISTTHREADVIEW,
+                                                 DBTREE::url_dat( get_url() ),
+                                                 DBTREE::article_subject( get_url() ), TYPE_THREAD );
+
     if( m_show_instdialog ) show_instruct_diag();
+
+    if( m_show_closedialog && !number_load && is_old() ){
+
+        SKELETON::MsgDiag mdiag( get_parent_win(), "DAT落ちしたためスレッドを取得できませんでした。\n\nタブを閉じますか？",
+                                 false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+        mdiag.set_default_response( Gtk::RESPONSE_YES );
+        if( mdiag.run() == Gtk::RESPONSE_YES ) close_view();
+    }
 }
 
 
@@ -490,7 +512,7 @@ void ArticleViewMain::create_status_message()
     if( ! DBTREE::article_ext_err( url_article() ).empty() ) str_stat += "[ " + DBTREE::article_ext_err( url_article() ) + " ] ";
 
     ss_tmp << " / 速度 " << DBTREE::article_get_speed( url_article() )
-           << " / " << DBTREE::article_lng_dat( url_article() )/1024 << " k ] "
+           << " / " << DBTREE::article_lng_dat( url_article() )/1024 << " K ] "
            << str_stat;
 
     set_status( ss_tmp.str() );
@@ -502,6 +524,8 @@ void ArticleViewMain::create_status_message()
 //
 void ArticleViewMain::show_instruct_diag()
 {
+    m_show_instdialog = false;
+
     SKELETON::MsgCheckDiag mdiag( get_parent_win(), 
                                   "スレビューからスレ一覧表示に戻る方法として\n\n(1) マウスジェスチャを使う\n(マウス右ボタンを押しながら左または下にドラッグして右ボタンを離す)\n\n(2) マウスの5ボタンを押す\n\n(3) Alt+x か h か ← を押す\n\n(4) ツールバーのスレ一覧アイコンを押す\n\n(5) 表示メニューからスレ一覧を選ぶ\n\nなどがあります。詳しくはオンラインマニュアルを参照してください。"
                                   , "今後表示しない(_D)"
@@ -510,7 +534,6 @@ void ArticleViewMain::show_instruct_diag()
     mdiag.run();
 
     if( mdiag.get_chkbutton().get_active() ) CONFIG::set_instruct_tglart( false );
-    m_show_instdialog = false;
 }
 
 
