@@ -13,7 +13,8 @@
 
 #include "jdlib/misctime.h"
 
-#include "controlid.h"
+#include "control/controlid.h"
+
 #include "command.h"
 
 #include <sys/time.h>
@@ -58,12 +59,12 @@ ArticleViewPreview::~ArticleViewPreview()
 //
 // viewの操作
 //
-void ArticleViewPreview::operate_view( const int& control )
+const bool ArticleViewPreview::operate_view( const int control )
 {
-    if( control == CONTROL::None ) return;
+    if( control == CONTROL::None ) return false;
 
     // スクロール系操作
-    if( drawarea()->set_scroll( control ) ) return;
+    if( drawarea()->set_scroll( control ) ) return true;
 
     switch( control ){
 
@@ -89,17 +90,24 @@ void ArticleViewPreview::operate_view( const int& control )
             break;
 
         case CONTROL::TabLeft:
+        case CONTROL::TabLeftUpdated:
             MESSAGE::get_admin()->set_command( "tab_left" );
             break;
 
         case CONTROL::TabRight:
+        case CONTROL::TabRightUpdated:
             MESSAGE::get_admin()->set_command( "tab_right" );
         break;
 
         case CONTROL::FocusWrite:
-            MESSAGE::get_admin()->set_command( "focus_writebutton" );
+            MESSAGE::get_admin()->set_command( "focus_button_write" );
         break;
+
+        default:
+            return false;
     }
+
+    return true;
 }
 
 
