@@ -14,14 +14,16 @@
 #include "icons/iconmanager.h"
 
 #include "jdlib/miscutil.h"
+#include "jdlib/jdregex.h"
+#include "jdlib/miscmsg.h"
 
 #include "global.h"
 #include "type.h"
 #include "viewfactory.h"
-#include "dndmanager.h"
 #include "sharedbuffer.h"
 #include "session.h"
 #include "command.h"
+#include "dndmanager.h"
 
 BOARD::BoardAdmin *instance_boardadmin = NULL;
 
@@ -51,7 +53,7 @@ BoardAdmin::BoardAdmin( const std::string& url )
     get_notebook()->set_fixtab( false );
     if( ! SESSION::get_show_board_tab() ) get_notebook()->set_show_tabs( false );
 
-    setup_menu( false );
+    setup_menu();
 }
 
 
@@ -78,8 +80,8 @@ void BoardAdmin::restore( const bool only_locked )
     const bool online = SESSION::is_online();
     SESSION::set_online( false );
 
-    std::list< std::string >& list_url = SESSION::get_board_URLs();
-    std::list< std::string >::iterator it_url = list_url.begin();
+    const std::list< std::string >& list_url = SESSION::get_board_URLs();
+    std::list< std::string >::const_iterator it_url = list_url.begin();
 
     std::list< bool > list_locked = SESSION::get_board_locked();
     std::list< bool >::iterator it_locked = list_locked.begin();
@@ -96,6 +98,12 @@ void BoardAdmin::restore( const bool only_locked )
         // ロックされているものだけ表示
         if( only_locked && ! lock ) continue;
 
+        // 板がDBに登録されていない場合は表示しない
+        if( DBTREE::url_boardbase( *it_url ).empty() ){
+            MISC::ERRMSG(  *it_url + " is not registered" );
+            continue;
+        }
+
         if( page == SESSION::board_page() ) set_page_num = get_tab_nums();
 
         COMMAND_ARGS command_arg = url_to_openarg( *it_url, true, lock );
@@ -109,13 +117,35 @@ void BoardAdmin::restore( const bool only_locked )
 
 COMMAND_ARGS BoardAdmin::url_to_openarg( const std::string& url, const bool tab, const bool lock )
 {
-    COMMAND_ARGS command_arg;
+    JDLIB::Regex regex;
 
+    COMMAND_ARGS command_arg;
     command_arg.command = "open_view";
-    command_arg.url = url;
+    command_arg.url = std::string();
     if( tab ) command_arg.arg1 = "true";  // タブで開く
     command_arg.arg2 = "false";           // 既に開いているかチェック
-    if( lock ) command_arg.arg3 = "lock";
+    if( lock ) command_arg.arg3 = "lock"; // 開き方のモード ( Admin::open_view 参照 )
+
+#ifdef _DEBUG
+    std::cout << "BoardAdmin::url_to_openarg url = " << url << std::endl;
+#endif    
+
+    // 次スレ検索
+    if( regex.exec( std::string( "(.*)" ) + NEXT_SIGN + ARTICLE_SIGN + "(.*)" + TIME_SIGN, url )){
+
+        command_arg.url = regex.str( 1 );
+
+        command_arg.arg4 = "NEXT";
+        command_arg.arg5 = regex.str( 2 );
+    }
+
+    // スレビュー
+    else{
+
+        command_arg.url = url;
+
+        command_arg.arg4 = "MAIN";
+    }
 
     return command_arg;
 }
@@ -130,11 +160,10 @@ void BoardAdmin::switch_admin()
 //
 // リストで与えられたページをタブで連続して開くとき(Admin::open_list())の引数セット
 //
-COMMAND_ARGS BoardAdmin::get_open_list_args( const std::string& url )
+COMMAND_ARGS BoardAdmin::get_open_list_args( const std::string& url, const COMMAND_ARGS& command_list )
 {
     COMMAND_ARGS command_arg;
-
-    CORE::core_set_command( "set_history_board", url );
+    command_arg.arg4 = "MAIN";
 
     return command_arg;
 }
@@ -150,7 +179,7 @@ void BoardAdmin::show_toolbar()
         m_toolbar = new BoardToolBar();
         get_notebook()->append_toolbar( *m_toolbar );
 
-        if( SESSION::get_show_board_toolbar() ) m_toolbar->show_toolbar();
+        if( SESSION::get_show_board_toolbar() ) m_toolbar->open_buttonbar();
     }
 
     get_notebook()->show_toolbar();
@@ -164,18 +193,67 @@ void BoardAdmin::toggle_toolbar()
 {
     if( ! m_toolbar ) return;
 
-    if( SESSION::get_show_board_toolbar() ) m_toolbar->show_toolbar();
-    else m_toolbar->hide_toolbar();
+#ifdef _DEBUG    
+    std::cout << "BoardAdmin::toggle_toolbar\n";
+#endif
+
+    // 検索関係の wiget の位置を変更
+    m_toolbar->unpack_pack();
+
+    if( SESSION::get_show_board_toolbar() ) m_toolbar->open_buttonbar();
+    else m_toolbar->close_buttonbar();
+
+    m_toolbar->close_searchbar();
+    m_toolbar->show_toolbar();
+}
+
+
+//
+// 検索バー表示
+//
+void BoardAdmin::open_searchbar()
+{
+    if( ! m_toolbar ) return;
+
+    // ツールバー表示時は検索関係の wiget はツールバーに表示されている
+    if( ! SESSION::get_show_board_toolbar() ){
+        m_toolbar->open_searchbar();
+        m_toolbar->show_toolbar();
+    }
+
+    m_toolbar->focus_entry_search();
+}
+
+
+//
+// 検索バー非表示
+//
+void BoardAdmin::close_searchbar()
+{
+    if( ! m_toolbar ) return;
+
+    if( ! SESSION::get_show_board_toolbar() ) m_toolbar->close_searchbar();
 }
 
 
 SKELETON::View* BoardAdmin::create_view( const COMMAND_ARGS& command )
 {
+    int type = CORE::VIEW_NONE; 
     CORE::VIEWFACTORY_ARGS view_args;
-    view_args.arg1 = command.arg4;
-    view_args.arg2 = command.arg5;    
 
-    SKELETON::View* view = CORE::ViewFactory( CORE::VIEW_BOARDVIEW, command.url, view_args );
+    // メインビュー
+    if( command.arg4 == "MAIN" ){
+        type = CORE::VIEW_BOARDVIEW;
+    }
+    else if( command.arg4 == "NEXT" ){
+        type = CORE::VIEW_BOARDNEXT;
+        view_args.arg1 = command.arg5;
+    }
+    else return NULL;
+
+    SKELETON::View* view = CORE::ViewFactory( type, command.url, view_args );
+    assert( view != NULL );
+
     return view;
 }
 
@@ -195,44 +273,46 @@ void BoardAdmin::command_local( const COMMAND_ARGS& command )
             if( view ) view->set_command( "update_columns" );
         }
     }
+
+    // 指定したスレを強調して表示
+    else if( command.command == "draw_bg_articles" ){
+
+        SKELETON::View* view = get_view( command.url );
+        if( view ) view->set_command( "draw_bg_articles" );
+    }
 }
 
 
 //
-// タブのD&Dを開始
+// タブをお気に入りにドロップした時にお気に入りがデータ送信を要求してきた
 //
-void BoardAdmin::slot_drag_begin( int page )
+void BoardAdmin::slot_drag_data_get( Gtk::SelectionData& selection_data, const int page )
 {
+#ifdef _DEBUG    
+    std::cout << "BoardAdmin::slot_drag_data_get page = " << page  << std::endl;
+#endif
+
     SKELETON::View* view = ( SKELETON::View* )get_notebook()->get_nth_page( page );
-    if( !view ) return;
+    if( ! view ) return;
 
-    std::string url = view->get_url();
+    const std::string url = view->get_url();
     
-    CORE::DND_Begin( get_url() );
-
     CORE::DATA_INFO info;
     info.type = TYPE_BOARD;
     info.url = DBTREE::url_boardbase( url );
     info.name = DBTREE::board_name( info.url );
+    info.data = std::string();
+    info.path = Gtk::TreePath( "0" ).to_string();
+
+    if( info.url.empty() ) return;
 
 #ifdef _DEBUG    
-    std::cout << "BoardAdmin::slot_drag_begin " << info.name  << std::endl;
+    std::cout << "name = " << info.name << std::endl;
 #endif
 
-    CORE::SBUF_clear_info();
-    CORE::SBUF_append( info );
-}
+    CORE::DATA_INFO_LIST list_info;
+    list_info.push_back( info );
+    CORE::SBUF_set_list( list_info );
 
-
-
-//
-// タブのD&D終了
-//
-void BoardAdmin::slot_drag_end()
-{
-#ifdef _DEBUG    
-    std::cout << "BoardAdmin::slot_drag_end\n";
-#endif
-
-    CORE::DND_End();
+    selection_data.set( DNDTARGET_FAVORITE, get_url() );
 }
