@@ -174,6 +174,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_localrule = CORE::ViewFactory( CORE::VIEW_ARTICLEINFO, get_url() );
 
     // プロキシ
+    std::string host;
     m_vbox_proxy.set_border_width( 16 );
     m_vbox_proxy.set_spacing( 8 );
 
@@ -184,7 +185,9 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
         case DBTREE::PROXY_DISABLE: m_proxy_frame.rd_disable.set_active(); break;
         case DBTREE::PROXY_LOCAL: m_proxy_frame.rd_local.set_active(); break;
     }
-    m_proxy_frame.entry_host.set_text( DBTREE::board_get_local_proxy( get_url() ) );
+    if( DBTREE::board_get_local_proxy_basicauth( get_url() ).empty() ) host = DBTREE::board_get_local_proxy( get_url() );
+    else host = DBTREE::board_get_local_proxy_basicauth( get_url() ) + "@" + DBTREE::board_get_local_proxy( get_url() );
+    m_proxy_frame.entry_host.set_text( host );
     m_proxy_frame.entry_port.set_text( MISC::itostr( DBTREE::board_get_local_proxy_port( get_url() ) ) );
 
     switch( DBTREE::board_get_mode_local_proxy_w( get_url() ) ){
@@ -192,7 +195,9 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
         case DBTREE::PROXY_DISABLE: m_proxy_frame_w.rd_disable.set_active(); break;
         case DBTREE::PROXY_LOCAL: m_proxy_frame_w.rd_local.set_active(); break;
     }
-    m_proxy_frame_w.entry_host.set_text( DBTREE::board_get_local_proxy_w( get_url() ) );
+    if( DBTREE::board_get_local_proxy_basicauth_w( get_url() ).empty() ) host = DBTREE::board_get_local_proxy_w( get_url() );
+    else host = DBTREE::board_get_local_proxy_basicauth_w( get_url() ) + "@" + DBTREE::board_get_local_proxy_w( get_url() );
+    m_proxy_frame_w.entry_host.set_text( host );
     m_proxy_frame_w.entry_port.set_text( MISC::itostr( DBTREE::board_get_local_proxy_port_w( get_url() ) ) );
 
     m_vbox_proxy.pack_start( m_label_proxy, Gtk::PACK_SHRINK );
@@ -238,7 +243,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_label_abone_thread.set_text( "以下の数字が0の時は、設定メニューの全体あぼ〜ん設定で指定した数字が用いられます。\nまたキャッシュにログがあるスレはあぼ〜んされません。\n\n" );
 
     m_label_number.set_text( "レス以上のスレをあぼ〜ん" );
-    m_spin_number.set_range( 0, 1001 );
+    m_spin_number.set_range( 0, 9999 );
     m_spin_number.set_increments( 1, 1 );
     m_spin_number.set_value( DBTREE::get_abone_number_thread( get_url() ) );
             
@@ -247,7 +252,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_hbox_number.pack_start( m_label_number, Gtk::PACK_SHRINK );
 
     m_label_hour.set_text( "時間以上スレ立てから経過したスレをあぼ〜ん" );
-    m_spin_hour.set_range( 0, 1000 );
+    m_spin_hour.set_range( 0, 9999 );
     m_spin_hour.set_increments( 1, 1 );
     m_spin_hour.set_value( DBTREE::get_abone_hour_thread( get_url() ) );
             
@@ -424,8 +429,7 @@ void Preferences::slot_ok_clicked()
 }
 
 
-bool Preferences::slot_timeout( int timer_number )
+void Preferences::timeout()
 {
     if( m_localrule ) m_localrule->clock_in();    
-    return true;
 }
