@@ -47,6 +47,18 @@ namespace CONTROL
 
         TabRight,
         TabLeft,
+        TabRightUpdated,
+        TabLeftUpdated,
+
+        TabNum1,
+        TabNum2,
+        TabNum3,
+        TabNum4,
+        TabNum5,
+        TabNum6,
+        TabNum7,
+        TabNum8,
+        TabNum9,
 
         PreBookMark,
         NextBookMark,
@@ -155,6 +167,10 @@ namespace CONTROL
         LiveStartStop,
 
         SearchNextArticle,
+        SearchWeb,
+        SearchTitle,
+        SearchCacheLocal,
+        SearchCacheAll,
 
         PopupWarpButton, // 以下、マウスボタン専用の設定
         ReferResButton, 
