@@ -11,6 +11,9 @@
 
 #include "cache.h"
 
+#ifdef _DEBUG
+#include "controlutil.h"
+#endif
 
 using namespace CONTROL;
 
@@ -38,6 +41,8 @@ void MouseConfig::load_conf()
     SETMOTION( "Left", MOUSECONF_Left );
     SETMOTION( "TabRight", MOUSECONF_TabRight );
     SETMOTION( "TabLeft", MOUSECONF_TabLeft );
+    SETMOTION( "TabRightUpdated", MOUSECONF_TabRightUpdated );
+    SETMOTION( "TabLeftUpdated", MOUSECONF_TabLeftUpdated );
     SETMOTION( "ToggleArticle", MOUSECONF_ToggleArticle );
     SETMOTION( "Home", MOUSECONF_Home );
     SETMOTION( "End", MOUSECONF_End );
@@ -54,6 +59,8 @@ void MouseConfig::load_conf()
     // ARTICLE
     SETMOTION( "GotoNew", MOUSECONF_GotoNew );
     SETMOTION( "SearchNextArticle", MOUSECONF_SearchNextArticle );
+    SETMOTION( "SearchWeb", MOUSECONF_SearchWeb );
+    SETMOTION( "SearchTitle", MOUSECONF_SearchTitle );
     SETMOTION( "LiveStartStop", MOUSECONF_LiveStartStop );
 
     // IMAGE
