@@ -25,21 +25,35 @@ void DBIMG::delete_root()
 }
 
 
-bool DBIMG::is_loadable( const std::string& url )
-{
-    if( instance_dbimg_root ) return instance_dbimg_root->is_loadable( url );
 
-    return false;
+const int DBIMG::get_type_ext( const std::string& url )
+{
+    if( instance_dbimg_root ) return instance_dbimg_root->get_type_ext( url );
+    return T_UNKNOWN;
 }
 
 
-bool DBIMG::is_loadable( const char* url, int n )
+const int DBIMG::get_image_type( const unsigned char *sign )
 {
-    if( instance_dbimg_root ) return instance_dbimg_root->is_loadable( url, n );
-
-    return false;
+    if( instance_dbimg_root ) return instance_dbimg_root->get_image_type( sign );
+    return T_UNKNOWN;
 }
 
+const int DBIMG::get_type_ext( const char* url, int n )
+{
+    if( instance_dbimg_root )  return instance_dbimg_root->get_type_ext( url, n );
+    return T_UNKNOWN;
+}
+
+
+const int DBIMG::get_type_real( const std::string& url )
+{
+    int type = T_UNKNOWN;
+    DBIMG::Img* img = DBIMG::get_img( url );
+    if( img ) type = img->get_type();
+
+    return type;
+}
 
 
 DBIMG::Img* DBIMG::get_img( const std::string& url )
@@ -49,7 +63,7 @@ DBIMG::Img* DBIMG::get_img( const std::string& url )
 }
 
 
-std::string DBIMG::get_cache_path( const std::string& url )
+const std::string DBIMG::get_cache_path( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->get_cache_path();
@@ -58,10 +72,10 @@ std::string DBIMG::get_cache_path( const std::string& url )
 }
 
 
-void DBIMG::download_img( const std::string& url, const std::string& refurl )
+void DBIMG::download_img( const std::string& url, const std::string& refurl, const bool mosaic )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
-    if( img ) img->download_img( refurl );
+    if( img ) img->download_img( refurl, mosaic );
 }
 
 
@@ -73,7 +87,7 @@ void DBIMG::stop_load( const std::string& url )
 
 
 
-bool DBIMG::save( const std::string& url, Gtk::Window* parent, const std::string& path_to )
+const bool DBIMG::save( const std::string& url, Gtk::Window* parent, const std::string& path_to )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->save( parent, path_to );
@@ -94,7 +108,7 @@ void DBIMG::delete_all_files()
 }    
 
 
-int DBIMG::get_width( const std::string& url )
+const int DBIMG::get_width( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->get_width();
@@ -102,7 +116,7 @@ int DBIMG::get_width( const std::string& url )
 }
 
 
-int DBIMG::get_height( const std::string& url )
+const int DBIMG::get_height( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->get_height();
@@ -110,7 +124,7 @@ int DBIMG::get_height( const std::string& url )
 }
 
 
-bool DBIMG::is_cached( const std::string& url )
+const bool DBIMG::is_cached( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->is_cached();
@@ -118,7 +132,7 @@ bool DBIMG::is_cached( const std::string& url )
 }
 
 
-bool DBIMG::get_abone( const std::string& url )
+const bool DBIMG::get_abone( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->get_abone();
@@ -133,7 +147,7 @@ void DBIMG::set_abone( const std::string& url, bool abone )
 }
 
 
-bool DBIMG::is_loading( const std::string& url )
+const bool DBIMG::is_loading( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->is_loading();
@@ -142,7 +156,7 @@ bool DBIMG::is_loading( const std::string& url )
 }
 
 
-int DBIMG::get_code( const std::string& url )
+const int DBIMG::get_code( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->get_code();
@@ -150,7 +164,7 @@ int DBIMG::get_code( const std::string& url )
 }
 
 
-std::string DBIMG::get_str_code( const std::string& url )
+const std::string DBIMG::get_str_code( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->get_str_code();
@@ -158,7 +172,7 @@ std::string DBIMG::get_str_code( const std::string& url )
 }
 
 
-bool DBIMG::get_mosaic( const std::string& url )
+const bool DBIMG::get_mosaic( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->get_mosaic();
@@ -173,7 +187,14 @@ void DBIMG::set_mosaic( const std::string& url, bool mosaic )
 }
 
 
-bool DBIMG::is_zoom_to_fit( const std::string& url )
+void DBIMG::show_large_img( const std::string& url )
+{
+    DBIMG::Img* img = DBIMG::get_img( url );
+    if( img ) img->show_large_img();
+}
+
+
+const bool DBIMG::is_zoom_to_fit( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->is_zoom_to_fit();
@@ -188,7 +209,7 @@ void DBIMG::set_zoom_to_fit( const std::string& url, bool fit )
 }
 
 
-int DBIMG::get_size( const std::string& url )
+const int DBIMG::get_size( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->get_size();
@@ -203,7 +224,7 @@ void DBIMG::set_size( const std::string& url, int size )
 }
 
 
-std::string DBIMG::get_refurl( const std::string& url )
+const std::string DBIMG::get_refurl( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->get_refurl();
@@ -211,14 +232,14 @@ std::string DBIMG::get_refurl( const std::string& url )
 }
 
 
-size_t DBIMG::byte( const std::string& url )
+const size_t DBIMG::byte( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->current_length();
     return 0;
 }
 
-size_t DBIMG::get_filesize( const std::string& url )
+const size_t DBIMG::get_filesize( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->total_length();
@@ -226,13 +247,20 @@ size_t DBIMG::get_filesize( const std::string& url )
 }
 
 
-bool DBIMG::is_protected( const std::string& url )
+const bool DBIMG::is_protected( const std::string& url )
 {
     DBIMG::Img* img = DBIMG::get_img( url );
     if( img ) return img->is_protected();
     return true;
 }
 
+const bool DBIMG::is_fake( const std::string& url )
+{
+    DBIMG::Img* img = DBIMG::get_img( url );
+    if( img ) return img->is_fake();
+    return false;
+}
+
 
 void DBIMG::set_protect( const std::string& url, bool protect )
 {
