@@ -46,11 +46,11 @@ m_path_article_ext_info = CACHE::path_article_ext_info( m_url, m_id ); \
 #define GET_INFOVALUE(target,targetname) \
 do { \
 target = std::string(); \
-option = targetname; \
+const int n = strlen( targetname ); \
 it2 = it; \
-while( it2 != lines.end() && ( *it2 ).find( option ) != 0 ) ++it2; \
+while( it2 != lines.end() && ( ( *it2 ).c_str()[ 0 ] != targetname[ 0 ] || strncmp( ( *it2 ).c_str(), targetname, n ) != 0 ) ) ++it2; \
 if( it2 != lines.end() ){ \
-    target = ( *it2 ).substr( option.length() ); \
+    target = ( *it2 ).substr( n ); \
     it = ++it2; \
 } } while( false )
 
@@ -75,8 +75,9 @@ ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, boo
       m_number_max( MAX_RESNUMBER ),
       m_write_fixname( 0 ),
       m_write_fixmail( 0 ),
-      m_abone_transparent( 0 ),
-      m_abone_chain( 0 ),
+      m_abone_transparent( false ),
+      m_abone_chain( false ),
+      m_abone_age( false ),
       m_bookmarked_thread( false ),
       m_cached( cached ),
       m_read_info( 0 ),
@@ -120,6 +121,13 @@ const bool ArticleBase::empty()
 }
 
 
+// ID がこのスレのものかどうか
+const bool ArticleBase::equal( const std::string& datbase, const std::string& id )
+{
+    return ( id == m_id );
+}
+
+
 //
 // 移転する前のオリジナルのURL
 //
@@ -264,9 +272,20 @@ std::list< int > ArticleBase::get_res_posted()
 //
 // number番のレスを参照しているレス番号をリストにして取得
 //
-std::list< int > ArticleBase::get_res_reference( int number )
+std::list< int > ArticleBase::get_res_reference( const int number )
 {
-    return get_nodetree()->get_res_reference( number );
+    std::list< int > res_num;
+    res_num.push_back( number );
+    return get_res_reference( res_num );
+}
+
+
+//
+// res_num に含まれるレスを参照しているレス番号をリストにして取得
+//
+std::list< int > ArticleBase::get_res_reference( const std::list< int >& res_num )
+{
+    return get_nodetree()->get_res_reference( res_num );
 }
 
 
@@ -426,16 +445,29 @@ void ArticleBase::set_subject( const std::string& subject )
 }
 
 
-void ArticleBase::set_number( const int number )
+void ArticleBase::set_number( const int number, const bool is_online )
 {
-    if( number && number > m_number ){
+    if( ! number ) return;
+
+    m_status &= ~STATUS_BROKEN_SUBJECT;
+
+    if( number > m_number ){
 
         m_number = number;
 
         // キャッシュがあって更新可能になった場合は
-        // スレの場合はお気に入りとスレタブのアイコンを更新
+        // お気に入りとスレビューのタブのアイコンに更新マークを表示
         if( is_cached() && !( m_status & STATUS_UPDATE ) && m_number_load < m_number ) show_updateicon( true );
     }
+
+    // subject.txt に示されたレス数よりも実際の取得数の方が多い
+    else if( is_online && number < m_number ){
+#ifdef _DEBUG
+        std::cout << "ArticleBase::set_number : broken_subject " << get_subject() << " "
+                  << number << " / " << m_number << std::endl;
+#endif
+        m_status |= STATUS_BROKEN_SUBJECT;
+    }
 }
 
 
@@ -511,7 +543,7 @@ void ArticleBase::set_bookmarked_thread( const bool bookmarked )
 //
 const bool ArticleBase::enable_load()
 {
-    return ( is_cached() && ( m_status & STATUS_UPDATE ) );
+    return ( is_cached() && ( m_status & STATUS_UPDATE ) && ! ( m_status & STATUS_OLD ) );
 }
 
 
@@ -573,7 +605,7 @@ void ArticleBase::update_abone()
     if( ! m_nodetree ) return;
 
     get_nodetree()->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_vec_abone_res,
-                                     m_abone_transparent, m_abone_chain );
+                                     m_abone_transparent, m_abone_chain, m_abone_age );
 
     get_nodetree()->update_abone_all();
 }
@@ -583,10 +615,12 @@ void ArticleBase::update_abone()
 //
 // あぼーん状態のリセット(情報セットと状態更新)
 //
-void ArticleBase::reset_abone( std::list< std::string >& ids, std::list< std::string >& names
-                               ,std::list< std::string >& words,  std::list< std::string >& regexs
-                               ,const std::vector< char >& vec_abone_res
-                               ,const bool transparent, const bool chain )
+void ArticleBase::reset_abone( const std::list< std::string >& ids,
+                               const std::list< std::string >& names,
+                               const std::list< std::string >& words,
+                               const std::list< std::string >& regexs,
+                               const std::vector< char >& vec_abone_res,
+                               const bool transparent, const bool chain, const bool age )
 {
     if( empty() ) return;
 
@@ -620,6 +654,7 @@ void ArticleBase::reset_abone( std::list< std::string >& ids, std::list< std::st
     
     m_abone_transparent = transparent;
     m_abone_chain = chain;
+    m_abone_age = age;
 
     update_abone();
 
@@ -694,10 +729,11 @@ void ArticleBase::add_abone_word( const std::string& word )
 //
 // レスあぼーんのセット
 //
-void ArticleBase::set_abone_res( const int number, const bool set )
+void ArticleBase::set_abone_res( const int num_from, const int num_to, const bool set )
 {
     if( empty() ) return;
-    if( number <= 0 || number > MAX_RESNUMBER ) return;
+    if( num_from > num_to ) return;
+    if( num_from <= 0 || num_to >= MAX_RESNUMBER ) return;
 
 #ifdef _DEBUG
     std::cout << "ArticleBase::set_abone_res num = " << number << " set = " << set << std::endl;
@@ -705,7 +741,7 @@ void ArticleBase::set_abone_res( const int number, const bool set )
 
     if( ! m_vec_abone_res.size() ) m_vec_abone_res.resize( MAX_RESNUMBER );
 
-    m_vec_abone_res[ number ] = set;
+    for( int i = num_from; i <= num_to; ++i ) m_vec_abone_res[ i ] = set;
 
     update_abone();
 
@@ -717,7 +753,7 @@ void ArticleBase::set_abone_res( const int number, const bool set )
 //
 // 透明あぼーん更新
 //
-void ArticleBase::set_abone_transparent( bool set )
+void ArticleBase::set_abone_transparent( const bool set )
 {
     if( empty() ) return;
 
@@ -732,7 +768,7 @@ void ArticleBase::set_abone_transparent( bool set )
 //
 // 連鎖あぼーん更新
 //
-void ArticleBase::set_abone_chain( bool set )
+void ArticleBase::set_abone_chain( const bool set )
 {
     if( empty() ) return;
 
@@ -744,6 +780,20 @@ void ArticleBase::set_abone_chain( bool set )
 } 
 
 
+//
+// ageあぼーん更新
+//
+void ArticleBase::set_abone_age( const bool set )
+{
+    if( empty() ) return;
+
+    m_abone_age = set;
+
+    update_abone();
+
+    m_save_info = true;
+} 
+
 
 //
 // ブックマークの数
@@ -865,7 +915,7 @@ JDLIB::ConstPtr< NodeTreeBase >& ArticleBase::get_nodetree()
 
         // あぼーん情報のコピー
         m_nodetree->copy_abone_info( m_list_abone_id, m_list_abone_name, m_list_abone_word, m_list_abone_regex, m_vec_abone_res,
-                                     m_abone_transparent, m_abone_chain );
+                                     m_abone_transparent, m_abone_chain, m_abone_age );
 
         // 書き込み情報のコピー
         m_nodetree->copy_post_info( m_vec_posted );
@@ -982,7 +1032,7 @@ void ArticleBase::download_dat( const bool check_update )
 #ifdef _DEBUG
         std::cout << "old !\n";
 #endif       
-        CORE::core_set_command( "toggle_favorite_icon", m_url );
+        CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
 
         // update_article_finish コマンドを送らないとキャッシュが無くて
         // dat落ちしているスレのタブが空白になる
@@ -1060,8 +1110,9 @@ void ArticleBase::copy_article_info( const std::string& url_src )
     std::vector< char > vec_abone_res;
     const bool transparent = DBTREE::get_abone_transparent( url_src );
     const bool chain = DBTREE::get_abone_chain( url_src );
+    const bool age = DBTREE::get_abone_age( url_src );
 
-    reset_abone( ids, names ,words, regexs, vec_abone_res, transparent, chain );
+    reset_abone( ids, names ,words, regexs, vec_abone_res, transparent, chain, age );
 }
 
 
@@ -1109,18 +1160,19 @@ void ArticleBase::slot_load_finished()
     slot_node_updated();
 
     // HTTPコード取得
-    int old_code = m_code;
+    const int old_code = m_code;
     m_code = m_nodetree->get_code();
+    m_status &= ~STATUS_UPDATED;
 
     // 状態更新
-    int old_status = m_status;
+    const int old_status = m_status;
     if( m_code != HTTP_ERR ){
 
         // DAT落ち
         if( m_code == HTTP_REDIRECT || m_code == HTTP_NOT_FOUND ){
             m_status &= ~STATUS_NORMAL;
             m_status |= STATUS_OLD;
-            CORE::core_set_command( "toggle_favorite_icon", m_url );
+            CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
         }
 
         // 既にDAT落ち状態では無いときは通常状態にする
@@ -1143,11 +1195,15 @@ void ArticleBase::slot_load_finished()
         std::cout << "check_update code = " << m_code << std::endl;
 #endif
 
-        // スレタブとお気に入りとスレ一覧のアイコンを更新
+        // スレタブとお気に入りとスレ一覧のアイコンに更新マークをつける
         if( m_code == HTTP_OK || m_code == HTTP_PARTIAL_CONTENT ){
 
             show_updateicon( true );
 
+            // このスレが所属する板を更新可能状態にしてお気に入りやスレ一覧のタブのアイコンに更新マークを表示
+            DBTREE::board_show_updateicon( m_url, true );
+
+            // スレ一覧の ! 行のアイコンを更新マークにする
             CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
         }
 
@@ -1159,6 +1215,9 @@ void ArticleBase::slot_load_finished()
         std::cout << "check_update done\n";
 #endif
 
+        // 更新チェック時間を保存
+        save_info( true );
+
         // 次のスレを更新チェック
         CORE::get_checkupdate_manager()->pop_front();
 
@@ -1195,33 +1254,53 @@ void ArticleBase::slot_load_finished()
         const std::string pre_subject = DBTREE::article_subject( m_url_pre_article );
         if( ! pre_subject.empty() ){
 
+#ifdef _DEBUG
+            std::cout << "check next\n";
+#endif
+            int value = 0;
+
             const std::list< DBTREE::ArticleBase* >& list_subject = DBTREE::board_list_subject( m_url );
-            if( ! list_subject.size() ) return;
 
-            // 単語ベクトル作成
-            MISC::VEC_WORDS vec_words;
-            MISC::tfidf_create_vec_words( vec_words, pre_subject );
+            // subjectがキャッシュにある場合は TFIDF を使って類似度チェック
+            if( list_subject.size() ){
+#ifdef _DEBUG
+                std::cout << "use tfidf\n";
+#endif
+                // 単語ベクトル作成
+                MISC::VEC_WORDS vec_words;
+                MISC::tfidf_create_vec_words( vec_words, pre_subject );
 
-            // IDFベクトル計算
-            MISC::VEC_IDF vec_idf;
-            MISC::tfidf_create_vec_idf_from_board( vec_idf, pre_subject, list_subject, vec_words );
+                // IDFベクトル計算
+                MISC::VEC_IDF vec_idf;
+                MISC::tfidf_create_vec_idf_from_board( vec_idf, pre_subject, list_subject, vec_words );
 
-            // TFIDFベクトル計算
-            MISC::VEC_TFIDF vec_tfidf_src;
-            MISC::VEC_TFIDF vec_tfidf;
-            vec_tfidf_src.resize( vec_words.size() );
-            vec_tfidf.resize( vec_words.size() );
-            MISC::tfidf_calc_vec_tfifd( vec_tfidf_src, pre_subject, vec_idf, vec_words );
-            MISC::tfidf_calc_vec_tfifd( vec_tfidf, m_subject, vec_idf, vec_words );
+                // TFIDFベクトル計算
+                MISC::VEC_TFIDF vec_tfidf_src;
+                MISC::VEC_TFIDF vec_tfidf;
+                vec_tfidf_src.resize( vec_words.size() );
+                vec_tfidf.resize( vec_words.size() );
+                MISC::tfidf_calc_vec_tfifd( vec_tfidf_src, pre_subject, vec_idf, vec_words );
+                MISC::tfidf_calc_vec_tfifd( vec_tfidf, m_subject, vec_idf, vec_words );
 
-            // 類似度計算
-            const int value = ( int )( MISC::tfidf_cos_similarity( vec_tfidf_src, vec_tfidf ) * 10 + .5 );
+                value = ( int )( MISC::tfidf_cos_similarity( vec_tfidf_src, vec_tfidf ) * 10 + .5 );
+            }
+
+            // subject がキャッシュに無い場合はレーベンシュタイン距離を使って類似度チェック
+            else{
+#ifdef _DEBUG
+                std::cout << "use leven\n";
+#endif
+                const int MAXSTR = 256;
+                std::vector< std::vector< int > > dist( MAXSTR, std::vector< int >( MAXSTR ) );
+                value = 10 - ( int )( MISC::leven( dist, pre_subject, m_subject ) * 10 + .5 );
+            }
 
 #ifdef _DEBUG
             std::cout << "pre_subject = " << pre_subject << std::endl
                       << "subject = " << m_subject << std::endl
                       << "value = " << value << std::endl;
 #endif
+
             // このスレは m_url_pre_article の次スレとみなして情報をコピーする
             if( value >= CONFIG::get_threshold_next() ){
 
@@ -1242,7 +1321,9 @@ void ArticleBase::slot_load_finished()
 
                 relayout = true;
             }
-
+#ifdef _DEBUG
+            else std::cout << "not hit\n";
+#endif
         }
 
         m_url_pre_article = std::string();
@@ -1271,6 +1352,7 @@ void ArticleBase::slot_load_finished()
 
             if( m_number < m_number_load ) m_number = m_number_load;
 
+            m_status |= STATUS_UPDATED;
             show_updateicon( false );
 
             // 情報ファイルのパスをセット
@@ -1306,7 +1388,7 @@ void ArticleBase::slot_load_finished()
 
 
 //
-// 更新アイコン表示
+// お気に入りのアイコンとスレビューのタブのアイコンに更新マークを表示
 //
 // update == true の時に表示。falseなら戻す
 //
@@ -1319,31 +1401,48 @@ void ArticleBase::show_updateicon( const bool update )
 
     struct timeval tv;
     struct timezone tz;
-    if( gettimeofday( &tv, &tz ) != 0 ) m_check_update_time = tv;
+    if( gettimeofday( &tv, &tz ) == 0 ) m_check_update_time = tv;
 
     if( update ){
 
+        if( ! ( m_status & STATUS_UPDATE ) ){
+
 #ifdef _DEBUG
-        std::cout << "toggle_icon on\n";
+            std::cout << "toggle_icon on\n";
 #endif
 
-        if( ! ( m_status & STATUS_UPDATE ) ) m_save_info = true;
-        m_status |= STATUS_UPDATE;
+            m_save_info = true;
+            m_status |= STATUS_UPDATE;
 
-        CORE::core_set_command( "toggle_article_icon", m_url);
-        CORE::core_set_command( "toggle_favorite_icon", m_url );
+            // スレビューのタブのアイコン表示を更新
+            CORE::core_set_command( "toggle_article_icon", m_url);
+
+            CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
+        }
     }
     else{
 
+        // この if をコメントアウトしないと
+        //
+        // スレ一覧を開いてお気に入りにあるスレに更新マークを付ける → スレ一覧を閉じる
+        // 更新マークを付けたスレを開かないでJD終了(※) → 再起動してお気に入りで更新マークを付けたスレをクリック
+        // → お気に入りのアイコン表示が戻らない
+        //
+        // という問題が生じる( ※ の所でスレ情報が保存されていないので再起動すると STATUS_UPDATE が外れるため。
+        // 終了時にスレ情報を保存しようとすると終了処理が重くなる。)
+//        if( m_status & STATUS_UPDATE ){
+
 #ifdef _DEBUG
-        std::cout << "toggle_icon off\n";
+            std::cout << "toggle_icon off\n";
 #endif
 
-        if( m_status & STATUS_UPDATE ) m_save_info = true;
-        m_status &= ~STATUS_UPDATE;
+            m_save_info = true;
+            m_status &= ~STATUS_UPDATE;
 
-        // お気に入りのアイコン表示を戻す。スレタブのアイコンの方はArticleViewが戻す
-        CORE::core_set_command( "toggle_favorite_icon", m_url );
+            // サイドバーのアイコン表示を戻す
+            // スレビューのタブのアイコンはArticleViewがロード終了時に自動的に戻す
+            CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
+//        }
     }
 }
 
@@ -1370,7 +1469,7 @@ void ArticleBase::delete_cache( const bool cache_only )
 
     m_number_load = m_number_seen = m_number_before_load = 0;
     m_cached = false;
-    m_status = STATUS_UNKNOWN;
+    reset_status();
     m_date_modified.clear();
     memset( &m_access_time, 0, sizeof( struct timeval ) );
     memset( &m_check_update_time, 0, sizeof( struct timeval ) );
@@ -1397,6 +1496,7 @@ void ArticleBase::delete_cache( const bool cache_only )
         m_vec_abone_res.clear();
         m_abone_transparent = false;
         m_abone_chain = false;
+        m_abone_age = false;
         m_read_info = false;
         m_save_info = false;
         m_bookmarked_thread = false;
@@ -1418,8 +1518,8 @@ void ArticleBase::delete_cache( const bool cache_only )
     // BoardViewの行を更新
     CORE::core_set_command( "update_board_item", DBTREE::url_subject( m_url ), m_id );
 
-    // お気に入りのアイコン表示を戻す
-    CORE::core_set_command( "toggle_favorite_icon", m_url );
+    // サイドバーのアイコン表示を戻す
+    CORE::core_set_command( "toggle_sidebar_articleicon", m_url );
 }
 
 
@@ -1434,15 +1534,15 @@ bool ArticleBase::save_dat( const std::string& path_to )
     if( is_loading() ) return false;
 
     std::string dir = MISC::get_dir( path_to );
-    if( dir.empty() ) dir = SESSION::dir_dat_save();
+    if( dir.empty() ) dir = SESSION::get_dir_dat();
 
     std::string name = MISC::get_filename( path_to );
-    if( name.empty() ) name = MISC::get_filename( m_url );    
+    if( name.empty() ) name = get_id();
 
     std::string save_to = CACHE::copy_file( NULL, CACHE::path_dat( m_url ), dir + name, CACHE::FILE_TYPE_DAT );
 
     if( ! save_to.empty() ){
-        SESSION::set_dir_dat_save( MISC::get_dir( save_to ) );
+        SESSION::set_dir_dat( MISC::get_dir( save_to ) );
         return true;
     }
 
@@ -1482,7 +1582,6 @@ void ArticleBase::read_info()
 
         std::list< std::string > lines = MISC::get_lines( str_info );
         std::list < std::string >::iterator it = lines.begin(), it2;
-        std::string option; // GET_INFOVALUE　で使用
 
         // subject
         GET_INFOVALUE( m_subject, "subject = " );
@@ -1548,7 +1647,7 @@ void ArticleBase::read_info()
         if( ! str_tmp.empty() ) m_write_fixmail = atoi( str_tmp.c_str() );
 
         // 状態
-        m_status = STATUS_UNKNOWN;
+        reset_status();
         GET_INFOVALUE( str_tmp, "status = " );
         if( ! str_tmp.empty() ) m_status = atoi( str_tmp.c_str() );
 
@@ -1628,6 +1727,21 @@ void ArticleBase::read_info()
                 else m_vec_posted[ number ] = false;
             }
         }
+
+        // ageあぼーん
+        m_abone_age = false;
+        GET_INFOVALUE( str_tmp, "aboneage = " );
+        if( ! str_tmp.empty() ) m_abone_age = atoi( str_tmp.c_str() );
+
+        // 最終更新チェック時間
+        GET_INFOVALUE( str_tmp, "checktime = " );
+        if( ! str_tmp.empty() ){
+            list_tmp = MISC::split_line( str_tmp );
+            if( list_tmp.size() == 2 ){
+                it_tmp = list_tmp.begin();
+                m_check_update_time.tv_sec = ( atoi( ( *(it_tmp++) ).c_str() ) << 16 ) + atoi( ( *(it_tmp++) ).c_str() );
+            }
+        }
     }
 
     // キャッシュはあるけど情報ファイルが無い場合
@@ -1644,6 +1758,7 @@ void ArticleBase::read_info()
         CORE::core_set_command( "set_status","", "スレ情報更新中・・・しばらくお待ち下さい" );
         MISC::MSG( "updating " + m_url );
 
+        reset_status();
         set_subject( get_nodetree()->get_subject() );
         m_number_load = get_nodetree()->get_res_number();
 
@@ -1738,7 +1853,11 @@ void ArticleBase::save_info( const bool force )
 
     // 書き込み時間
     std::ostringstream ss_write;
-    ss_write << ( m_write_time.tv_sec >> 16 ) << " " << ( m_write_time.tv_sec & 0xffff ) << " " << m_write_time.tv_usec;
+    if( m_write_time.tv_sec ) ss_write << ( m_write_time.tv_sec >> 16 ) << " " << ( m_write_time.tv_sec & 0xffff ) << " " << m_write_time.tv_usec;
+
+    // 更新チェック時間
+    std::ostringstream ss_check;
+    if( m_check_update_time.tv_sec ) ss_check << ( m_check_update_time.tv_sec >> 16 ) << " " << ( m_check_update_time.tv_sec & 0xffff );
 
     // あぼーん情報
     std::string str_abone_id = MISC::listtostr( m_list_abone_id );
@@ -1787,6 +1906,8 @@ void ArticleBase::save_info( const bool force )
          << "aboneres = " << ss_abone_res.str() << std::endl
          << "bkmark_thread = " << m_bookmarked_thread << std::endl
          << "posted = " << ss_posted.str() << std::endl
+         << "aboneage = " << m_abone_age << std::endl
+         << "checktime = " << ss_check.str() << std::endl
     ;
 
 #ifdef _DEBUG
