@@ -35,6 +35,7 @@ namespace DBTREE
         JDLIB::ConstPtr< NodeTreeBase > m_nodetree;
 
         std::string m_url;           // dat ファイルのURL
+        std::string m_datbase;       // ベースアドレス
         std::string m_id;            // ID ( .datなどの拡張子付き  (例) 1234567.dat )
         std::string m_key;           // ID から拡張子を取った物
         std::string m_date_modified; // サーバのデータが更新された時間
@@ -59,7 +60,7 @@ namespace DBTREE
         struct timeval m_access_time;  // ユーザが最後にロードした時間
         struct timeval m_check_update_time;  // 最終更新チェック時間
         struct timeval m_write_time;   // 最終書き込み時間
-        std::string m_write_time_date; // 書き込み月日( string型 )
+        std::string m_write_time_date; // 最終書き込み月日( string型 )
         std::string m_write_name;      // 書き込み時の名前
         std::string m_write_mail;      // 書き込み時のメアド
         bool m_write_fixname;          // 書き込み時名前固定
@@ -73,6 +74,7 @@ namespace DBTREE
         std::vector< char > m_vec_abone_res; // レスあぼーん情報
         bool m_abone_transparent; // 透明あぼーん
         bool m_abone_chain; // 連鎖あぼーん
+        bool m_abone_age; // age ているレスをあぼーん
 
         // 「スレ」がスレ一覧でブックマークされているか
         bool m_bookmarked_thread;          
@@ -80,6 +82,9 @@ namespace DBTREE
         // 「レス」のブックマーク
         std::vector< char > m_vec_bookmark; // ブックマーク判定キャッシュ
 
+        // 自分が書き込んだレスか
+        std::vector< char > m_vec_posted;
+
         // HDDにキャッシュされているか
         bool m_cached;
 
@@ -89,14 +94,15 @@ namespace DBTREE
         // true ならunlock_impl()がコールバックされたときに情報保存
         bool m_save_info;
 
-        // キャッシュがあって、かつ新着の読み込みが可能
-        bool m_enable_load;
+        // 前スレのアドレス
+        // スレが未取得で、この変数がemptyで無いとき download_dat()を呼び出すと
+        // ロード終了時に次スレ移行チェックと前スレの情報のコピーをする
+        std::string m_url_pre_article;
 
       protected:
         void set_key( const std::string& key ){ m_key = key; }
         void set_since_time( time_t since ){ m_since_time = since; }
         void set_since_date( std::string since ){ m_since_date = since; }
-        void set_number_max( int number ){ m_number_max = number; }
         
       public:
 
@@ -107,6 +113,9 @@ namespace DBTREE
 
         const std::string& get_url() const { return m_url; }
 
+        // ID がこのスレのものかどうか
+        virtual const bool equal( const std::string& datbase, const std::string& id );
+
         // 移転があったときなどにdatファイルのベースアドレスを更新
         void update_datbase( const std::string& datbase );
 
@@ -126,6 +135,8 @@ namespace DBTREE
         const int get_number_seen() const{  return m_number_seen; }
         const int get_number_max() const { return m_number_max; }
 
+        void set_number_max( const int number ){ if( number > 0 ) m_number_max = number; }
+
         // スレ速度
         const int get_speed();
 
@@ -144,9 +155,9 @@ namespace DBTREE
         // 指定した発言者の名前のレス番号をリストにして取得
         std::list< int > get_res_name( const std::string& name );
 
-        // number番のレスの時刻
+        // number番のレスの時刻を文字列で取得
         // 内部で regex　を使っているので遅い
-        const std::string get_time( int number );
+        const std::string get_time_str( int number );
 
         // number番のレスの発言者ID( スレIDではなくて名前の横のID )
         const std::string get_id_name( int number );
@@ -169,8 +180,14 @@ namespace DBTREE
         // ブックマークをつけたレス番号をリストにして取得
         std::list< int > get_res_bm();
 
+        // 書き込みしたレス番号をリストにして取得
+        std::list< int > get_res_posted();
+
         // number番のレスを参照しているレス番号をリストにして取得
-        std::list< int > get_res_reference( int number );
+        std::list< int > get_res_reference( const int number );
+
+        // res_num に含まれるレスを参照しているレス番号をリストにして取得
+        std::list< int > get_res_reference( const std::list< int >& res_num );
 
         // URL を含むレス番号をリストにして取得
         std::list< int > get_res_with_url();
@@ -213,7 +230,18 @@ namespace DBTREE
         // 最終書き込み時間
         const time_t& get_write_time() const { return m_write_time.tv_sec; } // 秒
         const std::string& get_write_date() const { return m_write_time_date; } // string型
-        const time_t get_write_pass(); // 経過時間(秒)
+
+        // 書き込み数
+        const int get_num_posted();
+
+        // 自分の書き込みか
+        const bool is_posted( const int number );
+
+        // 自分の書き込みにレスしたか
+        const bool is_refer_posted( const int number );
+
+        // 書き込み履歴のリセット
+        void clear_post_history();
 
         // スレ立て時刻
         const time_t& get_since_time() const { return m_since_time; };
@@ -222,6 +250,7 @@ namespace DBTREE
         // 更新時間
         time_t get_time_modified();
         const std::string& get_date_modified() { return m_date_modified; }
+        void set_date_modified( const std::string& date ){ m_date_modified = date; }
 
         // スレが立ってからの経過時間( 時間 )
         const int get_hour();
@@ -235,45 +264,50 @@ namespace DBTREE
 
         // DAT落ちかどうかなどの状態 ( global.hで定義 )
         const int get_status() const{ return m_status; }
-        void set_status( int status ){ m_status = status; }
-        void reset_status();
+        void set_status( const int status ){ m_status = status; }
         
         void set_subject( const std::string& subject );
-        void set_number( int number );
-        void set_number_load( int number_load );
-        void set_number_seen( int number_seen );
+        void set_number( const int number, const bool is_online );
+        void set_number_load( const int number_load );
+        void set_number_seen( const int number_seen );
         void update_writetime();
 
         // キャッシュ削除
-        void delete_cache( const bool cache_only );
+        // cache_only == true の時はキャッシュだけ削除してスレ情報は消さない
+        virtual void delete_cache( const bool cache_only );
 
         // キャッシュ保存
         bool save_dat( const std::string& path_to );
 
         // HDDにキャッシュされているか
-        const bool is_cached() const { return m_cached; }  
+        const bool is_cached() const { return m_cached; }
+        void set_cached( const bool set ){ m_cached = set; }
 
         // キャッシュがarticlebaseに読み込まれている(nodetree!=NULL)か
         const bool is_cache_read() const { return ( m_nodetree ); }
 
         // キャッシュがあって、かつ新着の読み込みが可能
-        const bool enable_load() const { return m_enable_load; }
+        const bool enable_load();
 
         // キャッシュはあるが規定のレス数を越えていて、かつ全てのレスが既読
         const bool is_finished();
 
         // あぼーん情報
-        std::list< std::string > get_abone_list_id(){ return m_list_abone_id; }
-        std::list< std::string > get_abone_list_name(){ return m_list_abone_name; }
-        std::list< std::string > get_abone_list_word(){ return m_list_abone_word; }
-        std::list< std::string > get_abone_list_regex(){ return m_list_abone_regex; }
-        std::vector< char > get_abone_vec_res(){ return m_vec_abone_res; }
+        const std::list< std::string >& get_abone_list_id(){ return m_list_abone_id; }
+        const std::list< std::string >& get_abone_list_name(){ return m_list_abone_name; }
+        const std::list< std::string >& get_abone_list_word(){ return m_list_abone_word; }
+        const std::list< std::string >& get_abone_list_regex(){ return m_list_abone_regex; }
+        const std::vector< char >& get_abone_vec_res(){ return m_vec_abone_res; }
 
         // 透明
         const bool get_abone_transparent();
+
         // 連鎖
         const bool get_abone_chain();
 
+        // ageあぼーん
+        const bool get_abone_age() const { return m_abone_age; }
+
         // number番のレスがあぼーんされているか
         const bool get_abone( int number );
 
@@ -281,42 +315,55 @@ namespace DBTREE
         void update_abone();
 
         // あぼーん状態のリセット(情報セットと状態更新を同時におこなう)
-        void reset_abone( std::list< std::string >& ids, std::list< std::string >& names
-                          ,std::list< std::string >& words, std::list< std::string >& regexs
-                          ,std::vector< char >& vec_abone_res
-                          ,bool transparent, bool chain );
+        void reset_abone( const std::list< std::string >& ids,
+                          const std::list< std::string >& names,
+                          const std::list< std::string >& words,
+                          const std::list< std::string >& regexs,
+                          const std::vector< char >& vec_abone_res,
+                          const bool transparent, const bool chain, const bool age );
 
         // あぼ〜ん状態更新(reset_abone()と違って各項目ごと個別におこなう)
         void add_abone_id( const std::string& id );
         void add_abone_name( const std::string& name );
         void add_abone_word( const std::string& word );
-        void set_abone_res( const int number, const bool set );
-        void set_abone_transparent( bool set ); // 透明
-        void set_abone_chain( bool set ); // 連鎖
+        void set_abone_res( const int num_from, const int num_to, const bool set );
+        void set_abone_transparent( const bool set ); // 透明
+        void set_abone_chain( const bool set ); // 連鎖
+        void set_abone_age( const bool set ); // age
 
         // 「スレ」のブックマーク
-        void set_bookmarked_thread( bool bookmarked );
+        void set_bookmarked_thread( const bool bookmarked );
         const bool is_bookmarked_thread() const { return m_bookmarked_thread; }
 
         // 「レス」のブックマーク
-        int get_num_bookmark();
-        bool is_bookmarked( int number );
-        void set_bookmark( int number, bool set );
+        const int get_num_bookmark();
+        const bool is_bookmarked( const int number );
+        void set_bookmark( const int number, const bool set );
 
         // 情報ファイル読み込み
         void read_info();
 
         // 情報ファイル書き込み
         // キャッシュがあって、force = true の時は強制書き込み
-        void save_info( bool force );
+        virtual void save_info( const bool force );
 
         // スレッドのロード開始
         const bool is_loading();
         void stop_load();
-        void download_dat( const bool check_update );
 
-        // 更新アイコン表示
-        void show_updateicon( const bool update );
+        // スレッドのロード開始
+        // DAT落ちの場合はロードしないので、強制的にリロードしたいときは reset_status() で
+        // ステータスをリセットしてからロードする
+        // check_update : true の時はHEADによる更新チェックをおこなう
+        virtual void download_dat( const bool check_update );
+
+        // 前スレのアドレスを指定
+        // 前スレのアドレスをセットしてからdownload_dat()を呼び出すと
+        // ロード終了時( slot_load_finished() )に次スレ移行チェックをする
+        void set_url_pre_article( const std::string& url_pre_article );
+
+        // url_src で示されるスレの情報をコピー
+        void copy_article_info( const std::string& url_src );
 
       private:
 
@@ -326,10 +373,16 @@ namespace DBTREE
 
         virtual NodeTreeBase* create_nodetree(){ return NULL; }
 
+        void reset_status();
+
         void slot_node_updated();
         void slot_load_finished();
         virtual void unlock_impl();
 
+        // お気に入りのアイコンとスレビューのタブのアイコンに更新マークを表示
+        // update == true の時に表示。falseなら戻す
+        void show_updateicon( const bool update );
+
         // navi2ch互換情報ファイル書き込み
         void save_navi2ch_info();
     };
