@@ -11,6 +11,10 @@
 #include <string>
 #include <list>
 
+#ifdef _WIN32
+#include <sys/time.h>
+#endif
+
 namespace JDLIB
 {
     class LOADERDATA;
@@ -22,9 +26,11 @@ namespace DBTREE
     // ローカルプロキシ設定
     enum
     {
-        PROXY_GLOBAL,  // 全体設定使用
+        PROXY_GLOBAL = 0,  // 全体設定使用
         PROXY_DISABLE, // 全体設定無効
-        PROXY_LOCAL    // ローカル設定使用
+        PROXY_LOCAL,     // ローカル設定使用
+
+        PROXY_NUM
     };
 
     class Root;
@@ -490,7 +496,7 @@ namespace DBTREE
         bool start_checkking_if_board_moved();
 
         virtual ArticleBase* append_article( const std::string& datbase, const std::string& id, const bool cached );
-        virtual void parse_subject( const char* str_subject_txt ){}
+        virtual void parse_subject( const char* str_subject_txt, const bool is_online ){}
 
         std::list< std::string > get_filelist_in_cache();
 
