@@ -294,15 +294,21 @@ void DBTREE::board_set_list_cookies_for_write( const std::string& url, const std
 }
 
 
-const std::string DBTREE::board_hana_for_write( const std::string& url )
+const std::string DBTREE::board_keyword_for_write( const std::string& url )
 {
-    return DBTREE::get_board( url )->hana_for_write();
+    return DBTREE::get_board( url )->get_keyword_for_write();
 }
 
 
-void DBTREE::board_set_hana_for_write( const std::string& url, const std::string& hana )
+void DBTREE::board_set_keyword_for_write( const std::string& url, const std::string& keyword )
 {
-    DBTREE::get_board( url )->set_hana_for_write( hana );
+    DBTREE::get_board( url )->set_keyword_for_write( keyword );
+}
+
+
+void DBTREE::board_analyze_keyword_for_write( const std::string& url, const std::string& html )
+{
+    DBTREE::get_board( url )->analyze_keyword_for_write( html );
 }
 
 
@@ -317,6 +323,13 @@ const std::string DBTREE::board_ext( const std::string& url )
     return DBTREE::get_board( url )->get_ext();
 }
 
+
+const int DBTREE::board_status( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_status();
+}
+
+
 const int DBTREE::board_code( const std::string& url )
 {
     return DBTREE::get_board( url )->get_code();
@@ -335,9 +348,14 @@ void DBTREE::board_save_info( const std::string& url )
 }
 
 
-void DBTREE::board_download_subject( const std::string& url )
+void DBTREE::board_download_subject( const std::string& url, const std::string& url_update_view )
 {
-    DBTREE::get_board( url )->download_subject();
+    DBTREE::get_board( url )->download_subject( url_update_view, false );
+}
+
+const bool DBTREE::board_is_loading( const std::string& url )
+{
+    return DBTREE::get_board( url )->is_loading();
 }
 
 void DBTREE::board_stop_load( const std::string& url )
@@ -425,6 +443,11 @@ const int DBTREE::board_get_local_proxy_port( const std::string& url )
     return DBTREE::get_board( url )->get_local_proxy_port();
 }
 
+const std::string& DBTREE::board_get_local_proxy_basicauth( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_local_proxy_basicauth();
+}
+
 void DBTREE::board_set_mode_local_proxy( const std::string& url, int mode )
 {
     DBTREE::get_board( url )->set_mode_local_proxy( mode );
@@ -450,6 +473,11 @@ const std::string& DBTREE::board_get_local_proxy_w( const std::string& url )
     return DBTREE::get_board( url )->get_local_proxy_w();
 }
 
+const std::string& DBTREE::board_get_local_proxy_basicauth_w( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_local_proxy_basicauth_w();
+}
+
 const int DBTREE::board_get_local_proxy_port_w( const std::string& url )
 {
     return DBTREE::get_board( url )->get_local_proxy_port_w();
@@ -491,6 +519,13 @@ void DBTREE::board_set_write_mail( const std::string& url, const std::string& ma
 }
 
 
+// 全スレの書き込み履歴のリセット
+void DBTREE::clear_all_post_history()
+{
+    DBTREE::get_root()->clear_all_post_history();
+}
+
+
 void DBTREE::read_boardinfo_all()
 {
     DBTREE::get_root()->read_boardinfo_all();
@@ -536,6 +571,29 @@ time_t DBTREE::board_write_leftsec( const std::string& url )
     return DBTREE::get_board( url )->get_write_leftsec();
 }
 
+void DBTREE::board_show_updateicon( const std::string& url, const bool update )
+{
+    DBTREE::get_board( url )->show_updateicon( update );
+}
+
+const std::list< std::string > DBTREE::board_get_check_update_articles( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_check_update_articles();
+}
+
+// datファイルのインポート
+const std::string DBTREE::board_import_dat( const std::string& url, const std::string& filename )
+{
+    return DBTREE::get_board( url )->import_dat( filename );
+}
+
+// 板に属する全スレの書き込み履歴のリセット
+void DBTREE::board_clear_all_post_history( const std::string& url )
+{
+    DBTREE::get_board( url )->clear_all_post_history();
+}
+
+
 const int DBTREE::board_get_number_max_res( const std::string& url )
 {
     return DBTREE::get_board( url )->get_number_max_res();
@@ -564,74 +622,67 @@ const time_t DBTREE::board_last_access_time( const std::string& url )
 
 /////////////////////////////////////////////////
 
-std::list< std::string > DBTREE::get_abone_list_id_board( const std::string& url )
+
+const std::list< std::string >& DBTREE::get_abone_list_id_board( const std::string& url )
 {
-    return DBTREE::get_board( url )->get_abone_list_id();
+    return DBTREE::get_board( url )->get_abone_list_id_board();
 }
 
-std::list< std::string > DBTREE::get_abone_list_name_board( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_name_board( const std::string& url )
 {
-    return DBTREE::get_board( url )->get_abone_list_name();
+    return DBTREE::get_board( url )->get_abone_list_name_board();
 }
 
-std::list< std::string > DBTREE::get_abone_list_word_board( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_word_board( const std::string& url )
 {
-    return DBTREE::get_board( url )->get_abone_list_word();
+    return DBTREE::get_board( url )->get_abone_list_word_board();
 }
 
-std::list< std::string > DBTREE::get_abone_list_regex_board( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_regex_board( const std::string& url )
 {
-    return DBTREE::get_board( url )->get_abone_list_regex();
+    return DBTREE::get_board( url )->get_abone_list_regex_board();
 }
 
 void DBTREE::reset_abone_board( const std::string& url,
-                        std::list< std::string >& ids, std::list< std::string >& names,
-                        std::list< std::string >& words, std::list< std::string >& regexs )
+                                const std::list< std::string >& ids,
+                                const std::list< std::string >& names,
+                                const std::list< std::string >& words,
+                                const std::list< std::string >& regexs )
 {
-    DBTREE::get_board( url )->reset_abone( ids, names, words, regexs );
+    DBTREE::get_board( url )->reset_abone_board( ids, names, words, regexs );
 }
 
 
 void DBTREE::add_abone_id_board( const std::string& url, const std::string& id )
 {
-    DBTREE::get_board( url )->add_abone_id( id );
+    DBTREE::get_board( url )->add_abone_id_board( id );
 }
 
 void DBTREE::add_abone_name_board( const std::string& url, const std::string& name )
 {
-    DBTREE::get_board( url )->add_abone_name( name );
+    DBTREE::get_board( url )->add_abone_name_board( name );
 }
 
 void DBTREE::add_abone_word_board( const std::string& url, const std::string& word )
 {
-    DBTREE::get_board( url )->add_abone_word( word );
+    DBTREE::get_board( url )->add_abone_word_board( word );
 }
 
 
 /////////////////////////////////////////////////
 
 
-void DBTREE::update_abone_all_board()
-{
-    DBTREE::get_root()->update_abone_all_board();
-}
-
-void DBTREE::update_abone_board( const std::string& url )
-{
-    DBTREE::get_board( url )->update_abone_thread();
-}
-
-std::list< std::string > DBTREE::get_abone_list_thread( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_thread( const std::string& url )
 {
     return DBTREE::get_board( url )->get_abone_list_thread();
 }
 
-std::list< std::string > DBTREE::get_abone_list_word_thread( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_word_thread( const std::string& url )
 {
     return DBTREE::get_board( url )->get_abone_list_word_thread();
 }
 
-std::list< std::string > DBTREE::get_abone_list_regex_thread( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_regex_thread( const std::string& url )
 {
     return DBTREE::get_board( url )->get_abone_list_regex_thread();
 }
@@ -647,9 +698,22 @@ const int DBTREE::get_abone_hour_thread( const std::string& url )
 }
 
 
+void DBTREE::remove_old_abone_thread( const std::string& url )
+{
+    DBTREE::get_board( url )->remove_old_abone_thread();
+}
+
+void DBTREE::update_abone_thread()
+{
+    DBTREE::get_root()->update_abone_thread();
+}
+
 void DBTREE::reset_abone_thread( const std::string& url,
-                                 std::list< std::string >& threads, std::list< std::string >& words, std::list< std::string >& regexs,
-                                 const int number, const int hour )
+                                 const std::list< std::string >& threads,
+                                 const std::list< std::string >& words,
+                                 const std::list< std::string >& regexs,
+                                 const int number,
+                                 const int hour )
 {
     DBTREE::get_board( url )->reset_abone_thread( threads, words, regexs, number, hour );
 }
@@ -726,12 +790,6 @@ const std::string DBTREE::article_write_date( const std::string& url )
     return DBTREE::get_article( url )->get_write_date();
 }
 
-// 経過時間(秒
-const time_t DBTREE::article_write_pass( const std::string& url )
-{
-    return DBTREE::get_article( url )->get_write_pass();
-}
-
 
 const int DBTREE::article_status( const std::string& url )
 {
@@ -739,12 +797,6 @@ const int DBTREE::article_status( const std::string& url )
 }
 
 
-void DBTREE::article_reset_status( const std::string& url )
-{
-    DBTREE::get_article( url )->reset_status();
-}
-
-
 const int DBTREE::article_code( const std::string& url )
 {
     return DBTREE::get_article( url )->get_code();
@@ -801,6 +853,15 @@ void DBTREE::article_download_dat( const std::string& url, const bool check_upda
     DBTREE::get_article( url )->download_dat( check_update );
 }
 
+void DBTREE::article_set_url_pre_article( const std::string& url, const std::string& url_pre_article )
+{
+    DBTREE::get_article( url )->set_url_pre_article( url_pre_article );
+}
+
+void DBTREE::article_copy_article_info( const std::string& url, const std::string& url_src )
+{
+    DBTREE::get_article( url )->copy_article_info( url_src );
+}
 
 void DBTREE::article_stop_load( const std::string& url )
 {
@@ -813,6 +874,14 @@ const int DBTREE::article_get_speed( const std::string& url )
     return DBTREE::get_article( url )->get_speed();
 }
 
+
+// 書き込み履歴のリセット
+void DBTREE::article_clear_post_history( const std::string& url )
+{
+    DBTREE::get_article( url )->clear_post_history();
+}
+
+
 const std::string& DBTREE::get_agent( const std::string& url )
 {
     return DBTREE::get_board( url )->get_agent();
@@ -828,6 +897,11 @@ const int DBTREE::get_proxy_port( const std::string& url )
     return DBTREE::get_board( url )->get_proxy_port();
 }
 
+const std::string DBTREE::get_proxy_basicauth( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_proxy_basicauth();
+}
+
 const std::string DBTREE::get_proxy_host_w( const std::string& url )
 {
     return DBTREE::get_board( url )->get_proxy_host_w();
@@ -838,6 +912,11 @@ const int DBTREE::get_proxy_port_w( const std::string& url )
     return DBTREE::get_board( url )->get_proxy_port_w();
 }
 
+const std::string DBTREE::get_proxy_basicauth_w( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_proxy_basicauth_w();
+}
+
 
 const std::string DBTREE::localrule( const std::string& url )
 {
@@ -921,6 +1000,12 @@ const std::string DBTREE::create_newarticle_message( const std::string& url, con
 }
 
 
+const std::string DBTREE::get_write_referer( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_write_referer();
+}
+
+
 // キャッシュ削除
 void DBTREE::delete_article( const std::string& url, const bool cache_only )
 {
@@ -955,46 +1040,49 @@ void DBTREE::update_abone_all_article()
 }
 
 
-std::list< std::string > DBTREE::get_abone_list_id( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_id( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_list_id();
 }
 
 
-std::list< std::string > DBTREE::get_abone_list_name( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_name( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_list_name();
 }
 
-std::list< std::string > DBTREE::get_abone_list_word( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_word( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_list_word();
 }
 
-std::list< std::string > DBTREE::get_abone_list_regex( const std::string& url )
+const std::list< std::string >& DBTREE::get_abone_list_regex( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_list_regex();
 }
 
 
-std::vector< char > DBTREE::get_abone_vec_res( const std::string& url )
+const std::vector< char >& DBTREE::get_abone_vec_res( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_vec_res();
 }
 
 
-void DBTREE::reset_abone( const std::string& url, std::list< std::string >& ids, std::list< std::string >& names
-                          , std::list< std::string >& words, std::list< std::string >& regexs
-                          , std::vector< char >& vec_abone_res
-                          , bool transparent, bool chain)
+void DBTREE::reset_abone( const std::string& url,
+                          const std::list< std::string >& ids,
+                          const std::list< std::string >& names,
+                          const std::list< std::string >& words,
+                          const std::list< std::string >& regexs,
+                          const std::vector< char >& vec_abone_res,
+                          const bool transparent, const bool chain, const bool age )
 {
-    DBTREE::get_article( url )->reset_abone( ids, names, words, regexs, vec_abone_res, transparent, chain );
+    DBTREE::get_article( url )->reset_abone( ids, names, words, regexs, vec_abone_res, transparent, chain, age );
 }
 
 
-void DBTREE::set_abone_res( const std::string& url, const int number, const bool set )
+void DBTREE::set_abone_res( const std::string& url, const int num_from, const int num_to, const bool set )
 {
-    DBTREE::get_article( url )->set_abone_res( number, set );
+    DBTREE::get_article( url )->set_abone_res( num_from, num_to, set );
 }
 
 
@@ -1015,36 +1103,51 @@ void DBTREE::add_abone_word( const std::string& url, const std::string& word )
 }
 
 
+// 透明あぼーん
 const bool DBTREE::get_abone_transparent( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_transparent();
 }
 
 
-void DBTREE::set_abone_transparent( const std::string& url, bool set )
+void DBTREE::set_abone_transparent( const std::string& url, const bool set )
 {
     DBTREE::get_article( url )->set_abone_transparent( set );
 }
 
 
+// 連鎖あぼーん
 const bool DBTREE::get_abone_chain( const std::string& url )
 {
     return DBTREE::get_article( url )->get_abone_chain();
 }
 
 
-void DBTREE::set_abone_chain( const std::string& url, bool set )
+void DBTREE::set_abone_chain( const std::string& url, const bool set )
 {
     DBTREE::get_article( url )->set_abone_chain( set );
 }
 
 
+// ageあぼーん
+const bool DBTREE::get_abone_age( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_abone_age();
+}
+
+
+void DBTREE::set_abone_age( const std::string& url, const bool set )
+{
+    DBTREE::get_article( url )->set_abone_age( set );
+}
+
+
 const bool DBTREE::is_bookmarked_thread( const std::string& url )
 {
     return DBTREE::get_article( url )->is_bookmarked_thread();
 }
 
-void DBTREE::set_bookmarked_thread( const std::string& url, bool bookmarked )
+void DBTREE::set_bookmarked_thread( const std::string& url, const bool bookmarked )
 {
     DBTREE::get_article( url )->set_bookmarked_thread( bookmarked );
 }
@@ -1055,13 +1158,13 @@ const int DBTREE::get_num_bookmark( const std::string& url )
     return DBTREE::get_article( url )->get_num_bookmark();
 }
 
-const bool DBTREE::is_bookmarked( const std::string& url, int number )
+const bool DBTREE::is_bookmarked( const std::string& url, const int number )
 {
     return DBTREE::get_article( url )->is_bookmarked( number );
 }
 
 
-void DBTREE::set_bookmark( const std::string& url, int number, bool set )
+void DBTREE::set_bookmark( const std::string& url, const int number, const bool set )
 {
     DBTREE::get_article( url )->set_bookmark( number, set );
 }
