@@ -338,7 +338,7 @@ namespace DBTREE
                       const bool transparent, const bool chain, const bool age );
 
     // 個別のあぼーん情報のセットと更新
-    void set_abone_res( const std::string& url, const int number, const bool set );
+    void set_abone_res( const std::string& url, const int num_from, const int num_to, const bool set );
     void add_abone_id( const std::string& url, const std::string& id );
     void add_abone_name( const std::string& url, const std::string& name );
     void add_abone_word( const std::string& url, const std::string& word );
