@@ -92,6 +92,7 @@ namespace DBTREE
         std::vector< char > m_vec_abone_res; // レスあぼーん情報
         bool m_abone_transparent; // 透明あぼーん
         bool m_abone_chain; // 連鎖あぼーん
+        bool m_abone_age; // age ているレスはあぼーん
 
         // 自分が書き込んだレスか
         std::vector< char > m_vec_posted;
@@ -183,8 +184,8 @@ namespace DBTREE
         // URL を含むレス番号をリストにして取得
         std::list< int > get_res_with_url();
 
-        // number番のレスを参照しているレス番号をリストにして取得
-        std::list< int > get_res_reference( int number );
+        // res_num に含まれるレスを参照しているレス番号をリストにして取得
+        std::list< int > get_res_reference( const std::list< int >& res_num );
 
         // query を含むレス番号をリストにして取得
         // mode_or == true なら OR抽出
@@ -210,16 +211,18 @@ namespace DBTREE
 
         // ロード開始
         // check_update : HEADによる更新チェックのみ
-        void download_dat( const bool check_update );
+        virtual void download_dat( const bool check_update );
 
         // あぼーんしているか
         bool get_abone( int number );
 
         // あぼーん情報を親クラスのarticlebaseからコピーする
-        void copy_abone_info( std::list< std::string >& list_abone_id, std::list< std::string >& list_abone_name,
-                              std::list< std::string >& list_abone_word, std::list< std::string >& list_abone_regex,
+        void copy_abone_info( const std::list< std::string >& list_abone_id,
+                              const std::list< std::string >& list_abone_name,
+                              const std::list< std::string >& list_abone_word,
+                              const std::list< std::string >& list_abone_regex,
                               const std::vector< char >& vec_abone_res,
-                              const bool abone_transparent, const bool abone_chain );
+                              const bool abone_transparent, const bool abone_chain, const bool abone_age );
 
         // 全レスのあぼーん状態の更新
         // 発言数や参照数も更新する
@@ -304,14 +307,15 @@ namespace DBTREE
         void clear_abone();
 
         // from_number番から to_number 番までのレスのあぼーん状態を更新
-        void update_abone( int from_number, int to_number );
+        void update_abone( const int from_number, const int to_number );
 
         // あぼーんチェック
-        bool check_abone_res( int number );
-        bool check_abone_id( int number );
-        bool check_abone_name( int number );
-        bool check_abone_word( int number );
-        bool check_abone_chain( int number );
+        const bool check_abone_res( const int number );
+        const bool check_abone_id( const int number );
+        const bool check_abone_name( const int number );
+        const bool check_abone_mail( const int number );
+        const bool check_abone_word( const int number );
+        const bool check_abone_chain( const int number );
 
 
         // 参照数(num_reference)と色のクリア
@@ -339,20 +343,6 @@ namespace DBTREE
         // http://ime.nu/ などをリンクから削除
         bool remove_imenu( char* str_link );
     };
-
-
-
-    /////////////////////////////////////////////////////////
-
-
-    // ARTICLE::LayoutTree::append_html() で使用するダミークラス
-
-    class NodeTreeDummy : public NodeTreeBase
-    {
-      public:
-        NodeTreeDummy( const std::string& url, const std::string& date_modified );
-        virtual ~NodeTreeDummy();
-    };
 }
 
 #endif
