@@ -327,7 +327,7 @@ void Root::receive_finish()
 {
     if( get_code() != HTTP_OK ){
 
-        std::string msg = get_str_code() + "\n\n板一覧の読み込みに失敗しました。\n\nプロキシ設定や板一覧を取得するサーバのアドレスを確認して、ファイルメニューから板一覧の再読み込みをして下さい。\n板一覧取得サーバのアドレスはabout:configで確認出来ます。";
+        std::string msg = get_str_code() + "\n\n板一覧の読み込みに失敗したため板一覧は更新されませんでした。\n\nプロキシ設定や板一覧を取得するサーバのアドレスを確認して、ファイルメニューから板一覧の再読み込みをして下さい。\n板一覧取得サーバのアドレスはabout:configで確認出来ます。";
         SKELETON::MsgDiag mdiag( NULL, msg, false, Gtk::MESSAGE_ERROR );
         mdiag.run();
         MISC::ERRMSG( "bbsmenu load failed : " + get_str_code() );
@@ -1416,14 +1416,8 @@ void Root::save_movetable()
     
     CACHE::save_rawdata( file_move, movetable.str() );
 
-    // 板一覧に登録されているURL更新
-    CORE::core_set_command( "update_bbslist_item" );
-
-    // お気に入りに登録されているURL更新
-    CORE::core_set_command( "update_favorite_item" );
-
-    // 履歴メニューのURL更新
-    CORE::core_set_command( "update_history" );
+    // サイドバーに登録されているURL更新
+    CORE::core_set_command( "update_sidebar_item" );
 }
 
 
