@@ -26,6 +26,7 @@
 #include "global.h"
 #include "type.h"
 #include "prefdiagfactory.h"
+#include "usrcmdmanager.h"
 #include "httpcode.h"
 #include "session.h"
 
@@ -69,6 +70,15 @@ SKELETON::Admin* ImageViewBase::get_admin()
 }
 
 
+//
+// 親ウィンドウを取得
+//
+Gtk::Window* ImageViewBase::get_parent_win()
+{
+    return IMAGE::get_admin()->get_win();
+}
+
+
 //
 // 共通セットアップ
 //
@@ -127,7 +137,7 @@ void ImageViewBase::setup_common()
         action_group()->add( action, sigc::bind< int >( sigc::mem_fun( *this, &ImageViewBase::slot_resize_image ), tmp_size ) );
     }
 
-    action_group()->add( Gtk::Action::create( "Move_Menu", "移動(_M)" ) );
+    action_group()->add( Gtk::Action::create( "Move_Menu", ITEM_NAME_GO + std::string( "(_M)" ) ) );
     action_group()->add( Gtk::Action::create( "MoveHead", "先頭に移動(_H)" ), sigc::mem_fun( *this, &ImageViewBase::slot_move_head ) );
     action_group()->add( Gtk::Action::create( "MoveTail", "最後に移動(_T)" ), sigc::mem_fun( *this, &ImageViewBase::slot_move_tail ) );
 
@@ -137,15 +147,16 @@ void ImageViewBase::setup_common()
     action_group()->add( Gtk::Action::create( "CloseOther", "他の画像(_O)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_other_views ) );
     action_group()->add( Gtk::Action::create( "CloseLeft", "左←の画像(_L)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_left_views ) );
     action_group()->add( Gtk::Action::create( "CloseRight", "右→の画像(_R)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_right_views ) );
+    action_group()->add( Gtk::Action::create( "CloseError", "読み込みエラーの画像(_E)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_error_views ) );
     action_group()->add( Gtk::Action::create( "CloseAll", "全ての画像(_A)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_all_views ) );
 
     action_group()->add( Gtk::ToggleAction::create( "LockTab", "タブをロックする(_K)", std::string(), false ),
                          sigc::mem_fun( *this, &ImageViewBase::slot_lock ) );
 
-    action_group()->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く(_W)"),
+    action_group()->add( Gtk::Action::create( "OpenBrowser", ITEM_NAME_OPEN_BROWSER + std::string( "(_W)" ) ),
                          sigc::mem_fun( *this, &ImageViewBase::slot_open_browser ) );
     action_group()->add( Gtk::Action::create( "OpenRef", "参照元のレスを開く(_O)"), sigc::mem_fun( *this, &ImageViewBase::slot_open_ref ) );
-    action_group()->add( Gtk::Action::create( "CopyURL", "URLをコピー(_U)"), sigc::mem_fun( *this, &ImageViewBase::slot_copy_url ) );
+    action_group()->add( Gtk::Action::create( "CopyURL", ITEM_NAME_COPY_URL + std::string( "(_U)" ) ), sigc::mem_fun( *this, &ImageViewBase::slot_copy_url ) );
     action_group()->add( Gtk::Action::create( "Save", "Save"), sigc::mem_fun( *this, &ImageViewBase::slot_save ) );
     action_group()->add( Gtk::Action::create( "SaveAll", "全ての画像を保存(_A)..."), sigc::mem_fun( *this, &ImageViewBase::slot_save_all ) );
 
@@ -158,12 +169,19 @@ void ImageViewBase::setup_common()
 
     action_group()->add( Gtk::Action::create( "Preference", "プロパティ(_P)..."), sigc::mem_fun( *this, &ImageViewBase::show_preference ) );
 
+    const std::string usrcmd = CORE::get_usrcmd_manager()->create_usrcmd_menu( action_group() );
+    const int usrcmd_size = CORE::get_usrcmd_manager()->get_size();
+    for( int i = 0; i < usrcmd_size; ++i ){
+        Glib::RefPtr< Gtk::Action > act = CORE::get_usrcmd_manager()->get_action( action_group(), i );
+        if( act ) act->signal_activate().connect(
+            sigc::bind< int >( sigc::mem_fun( *this, &ImageViewBase::slot_usrcmd ), i ) );
+    }
+
     ui_manager() = Gtk::UIManager::create();    
     ui_manager()->insert_action_group( action_group() );
 
-    Glib::ustring str_ui = 
-
-    "<ui>"
+    // 画像ビューのメニュー
+    const std::string menu = 
 
     "<popup name='popup_menu'>"
 
@@ -191,6 +209,8 @@ void ImageViewBase::setup_common()
 
     "<menuitem action='OpenBrowser'/>"
     "<menuitem action='OpenRef'/>"
+    + usrcmd
+    + std::string( 
     "<separator/>"
 
     "<menuitem action='CopyURL'/>"
@@ -216,12 +236,11 @@ void ImageViewBase::setup_common()
 
     "<menuitem action='Preference'/>"
 
-
     "</popup>"
-
-    //////////////////////////
+    );
 
     // アイコンのメニュー
+    const std::string menu_icon = 
     
     "<popup name='popup_menu_icon'>"
 
@@ -242,6 +261,7 @@ void ImageViewBase::setup_common()
     "<menuitem action='CloseOther'/>"
     "<menuitem action='CloseLeft'/>"
     "<menuitem action='CloseRight'/>"
+    "<menuitem action='CloseError'/>"
     "</menu>"
     "<separator/>"
 
@@ -275,12 +295,14 @@ void ImageViewBase::setup_common()
     "<separator/>"
     "<menuitem action='Preference'/>"
 
-    "</popup>"
-
-    "</ui>";
-
-    ui_manager()->add_ui_from_string( str_ui );
+    "</popup>";
 
+    ui_manager()->add_ui_from_string(
+        "<ui>"
+        + menu
+        + menu_icon
+        + "</ui>"
+        );
 
     // ポップアップメニューにキーアクセレータやマウスジェスチャを表示
     Gtk::Menu* popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu" ) );
@@ -343,8 +365,8 @@ void ImageViewBase::reload()
 #endif
 
     std::string refurl = m_img->get_refurl();
-    const bool nomosaic = false;
-    m_img->download_img( refurl, nomosaic );
+    const bool mosaic = m_img->get_mosaic();
+    m_img->download_img( refurl, mosaic );
 }
 
 
@@ -434,6 +456,15 @@ void ImageViewBase::slot_close_right_views()
 }
 
 
+//
+// エラーの画像を閉じる
+//
+void ImageViewBase::slot_close_error_views()
+{
+    IMAGE::get_admin()->set_command( "close_error_views" );
+}
+
+
 
 //
 // 全ての画像を閉じる
@@ -449,7 +480,7 @@ void ImageViewBase::slot_close_all_views()
 //
 void ImageViewBase::show_preference()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( IMAGE::get_admin()->get_win(), CORE::PREFDIAG_IMAGE, get_url() );
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_IMAGE, get_url() );
 
     IMAGE::get_admin()->set_command_immediately( "disable_fold_win" ); // run 直前に呼ぶこと
     pref->run();
@@ -517,13 +548,53 @@ const bool ImageViewBase::operate_view( const int control )
             break;
 
         case CONTROL::TabLeft:
+        case CONTROL::TabLeftUpdated:
             IMAGE::get_admin()->set_command( "tab_left" );
             break;
 
         case CONTROL::TabRight:
+        case CONTROL::TabRightUpdated:
             IMAGE::get_admin()->set_command( "tab_right" );
             break;
 
+        // タブ位置(1-9)で移動
+        case CONTROL::TabNum1:
+            IMAGE::get_admin()->set_command( "tab_num", "", "1" );
+            break;
+
+        case CONTROL::TabNum2:
+            IMAGE::get_admin()->set_command( "tab_num", "", "2" );
+            break;
+
+        case CONTROL::TabNum3:
+            IMAGE::get_admin()->set_command( "tab_num", "", "3" );
+            break;
+
+        case CONTROL::TabNum4:
+            IMAGE::get_admin()->set_command( "tab_num", "", "4" );
+            break;
+
+        case CONTROL::TabNum5:
+            IMAGE::get_admin()->set_command( "tab_num", "", "5" );
+            break;
+
+        case CONTROL::TabNum6:
+            IMAGE::get_admin()->set_command( "tab_num", "", "6" );
+            break;
+
+        case CONTROL::TabNum7:
+            IMAGE::get_admin()->set_command( "tab_num", "", "7" );
+            break;
+
+        case CONTROL::TabNum8:
+            IMAGE::get_admin()->set_command( "tab_num", "", "8" );
+            break;
+
+        case CONTROL::TabNum9:
+            IMAGE::get_admin()->set_command( "tab_num", "", "9" );
+            break;
+
+        // スクロール
         case CONTROL::ScrollUpImage:
             IMAGE::get_admin()->set_command( "scroll_up" );
             break;
@@ -557,14 +628,14 @@ const bool ImageViewBase::operate_view( const int control )
 
             if( !m_img->is_protected() ){
 
-                SKELETON::MsgDiag mdiag( IMAGE::get_admin()->get_win(),
+                SKELETON::MsgDiag mdiag( get_parent_win(),
                                          "画像を削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
                 mdiag.set_default_response( Gtk::RESPONSE_NO );
                 if( mdiag.run() == Gtk::RESPONSE_YES ) delete_view();
             }
             else{
 
-                SKELETON::MsgDiag mdiag( IMAGE::get_admin()->get_win(), "キャッシュ保護されています" );
+                SKELETON::MsgDiag mdiag( get_parent_win(), "キャッシュ保護されています" );
                 mdiag.run();
             }
 
@@ -742,7 +813,7 @@ void ImageViewBase::slot_reload_force()
     if( ! m_enable_menuslot ) return;
 
     if( ! SESSION::is_online() ){
-        SKELETON::MsgDiag mdiag( NULL, "オフラインです" );
+        SKELETON::MsgDiag mdiag( get_parent_win(), "オフラインです" );
         mdiag.run();
         return;
     }
@@ -776,7 +847,7 @@ void ImageViewBase::slot_cancel_mosaic()
         }
         type += "です。";
 
-        SKELETON::MsgDiag mdiag( IMAGE::get_admin()->get_win(),
+        SKELETON::MsgDiag mdiag( get_parent_win(),
                                  "拡張子が偽装されています。" + type + "\n\nモザイクを解除しますか？",
                                  false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
 
@@ -1138,6 +1209,29 @@ void ImageViewBase::activate_act_before_popupmenu( const std::string& url )
         else act->set_sensitive( false );
     }
 
+    // ユーザコマンド
+    // 選択不可かどうか判断して visible か sensitive にする
+    const std::string url_article = DBTREE::url_dat( m_img->get_refurl() );
+    CORE::get_usrcmd_manager()->toggle_sensitive( action_group(), url_article, get_url(), "" );
+
     m_enable_menuslot = true;
 }
 
+
+//
+// ユーザコマンド実行
+//
+void ImageViewBase::slot_usrcmd( int num )
+{
+    int from, to;
+    std::string num_str;
+    const std::string url_article = DBTREE::url_dat( m_img->get_refurl(), from, to, num_str );
+
+    CORE::core_set_command( "exec_usr_cmd" ,
+                            url_article,
+                            MISC::itostr( num ),
+                            get_url(),
+                            "",
+                            MISC::itostr( from )
+        );
+}
