@@ -8,8 +8,16 @@
 
 #include <gtkmm.h>
 
+#ifndef _WIN32
 namespace CORE
 {
+    enum
+    {
+        FIFO_OK = 0,
+        FIFO_OPEN_ERROR,
+        FIFO_CREATE_ERROR
+    };
+
     class IOMonitor
     {
         // FIFOのファイルディスクリプタ
@@ -21,6 +29,9 @@ namespace CORE
         // I/Oの架け橋
         Glib::RefPtr< Glib::IOChannel > m_iochannel;
 
+        // FIFOの状態
+        int m_fifo_stat;
+
         // メインプロセスか否か
         bool m_main_process;
 
@@ -40,6 +51,9 @@ namespace CORE
         IOMonitor();
         ~IOMonitor();
 
+        // FIFOの状態を取得
+        int get_fifo_stat(){ return m_fifo_stat; }
+
         // メインプロセスか否かを取得
         bool is_main_process(){ return m_main_process; }
 
@@ -47,5 +61,6 @@ namespace CORE
         bool send_command( const char* command );
     };
 }
+#endif //_WIN32
 
 #endif
