@@ -40,13 +40,17 @@ struct XSMPDATA
 };
 #endif
 
+#ifdef _WIN32
+#include <windows.h>
+#endif
+
 enum
 {
     MAX_SAFE_ARGC = 4,   // 引数の数の制限値
     MAX_SAFE_ARGV = 1024 // 各引数の文字列の制限値
 };
 
-WinMain* Win_Main = NULL;
+JDWinMain* Win_Main = NULL;
 
 
 // バックアップ復元
@@ -107,7 +111,11 @@ void restore_bkup()
 // SIGINTのハンドラ
 void sig_handler( int sig )
 {
+#ifdef _WIN32
+    if( sig == SIGINT ){
+#else
     if( sig == SIGHUP || sig == SIGINT || sig == SIGQUIT ){
+#endif
 
 #ifdef _DEBUG
         std::cout << "sig_handler sig = " << sig << std::endl;
@@ -299,6 +307,8 @@ void usage( const int status )
     //"        URL open of BBS etc by Tab\n"
     "-m, --multi\n"
     "        Does not terminate even if it is a subprocess\n"
+    "-s, --skip-setup\n"
+    "        Skip the setup dialog\n"
     "-V, --version\n"
     "        Display version of this program\n";
 
@@ -338,16 +348,18 @@ int main( int argc, char **argv )
         { "help", 0, 0, 'h' },
         //{ "tab", 1, 0, 't' },
         { "multi", 0, 0, 'm' },
+        { "skip-setup", 0, 0, 's' },
         { "version", 0, 0, 'V' },
         { 0, 0, 0, 0 }
     };
 
-    char* url = NULL;
+    std::string url;
     bool multi_mode = false;
+    bool skip_setupdiag = false;
 
     // -h, -t <url>, -m, -V
     int opt = 0;
-    while( ( opt = getopt_long( argc, argv, "ht:mV", options, NULL ) ) != -1 )
+    while( ( opt = getopt_long( argc, argv, "ht:msV", options, NULL ) ) != -1 )
     {
         switch( opt )
         {
@@ -363,8 +375,14 @@ int main( int argc, char **argv )
                 multi_mode = true;
                 break;
 
-            case 'V':
-                std::cout << "JD " << ENVIRONMENT::get_jdversion() << ", " << ENVIRONMENT::get_jdcopyright() << std::endl;
+            case 's':
+                skip_setupdiag = true;
+                break;
+
+            case 'V': // バージョンと完全なconfigureオプションを表示
+                std::cout << "JD " << ENVIRONMENT::get_jdversion() << ", " <<
+                ENVIRONMENT::get_jdcopyright() << "\n"
+                "configure: " << ENVIRONMENT::get_configure_args( ENVIRONMENT::CONFIGURE_FULL ) << std::endl;
                 break;
 
             default:
@@ -372,18 +390,19 @@ int main( int argc, char **argv )
         }
     }
 
-    if( ! url )
+    if( url.empty() )
     {
         // 引数がURLのみの場合
         if( argc > optind )
         {
             url = argv[ optind ];
         }
-        // マルチモードでなく、URLを含まない引数だけの場合は終了
-        else if( optind > 1 && ! multi_mode ) return 0;
+        // -m 、-s でなく、URLを含まない引数だけの場合は終了
+        else if( optind > 1 && ! ( multi_mode || skip_setupdiag ) ) return 0;
     }
     /*---------------------------------------------------------------*/
 
+#ifndef _WIN32
     // SIGINT、SIGQUITのハンドラ設定
     struct sigaction sigact;
     sigset_t blockset;
@@ -406,6 +425,7 @@ int main( int argc, char **argv )
         fprintf( stderr, "sigaction failed\n" );
         exit( 1 );
     }
+#endif
 
 #ifdef _DEBUG_MEM_PROFILE
     g_mem_set_vtable( glib_mem_profiler_table );
@@ -474,32 +494,73 @@ int main( int argc, char **argv )
     }
 
     /*--- IOMonitor -------------------------------------------------*/
+#ifndef _WIN32
     CORE::IOMonitor iomonitor;
 
-    // 引数にURLがある
-    if( url )
+    // FIFOの状態をチェックする
+    if( iomonitor.get_fifo_stat() == CORE::FIFO_OK )
     {
-        // FIFOに書き込む
-        iomonitor.send_command( url );
+        // 引数にURLがある
+        if( ! url.empty() )
+        {
+            // ローカルファイルかどうかチェック
+            const std::string url_real = CACHE::get_realpath( url );
+            if( ! url_real.empty() ) url = url_real;
 
-        // マルチモードでなく、メインプロセスでもない場合は終了
-        if( ! multi_mode && ! iomonitor.is_main_process() ) return 0;
+            // FIFOに書き込む
+            iomonitor.send_command( url.c_str() );
+
+            // マルチモードでなく、メインプロセスでもない場合は終了
+            if( ! multi_mode && ! iomonitor.is_main_process() ) return 0;
+        }
+        // マルチモードでなく、メインプロセスでもない場合は問い合わせる
+        else if( ! multi_mode && ! iomonitor.is_main_process() )
+        {
+            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "JDは既に起動しています。起動しますか？",
+                                                                false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            int ret = mdiag->run();
+            delete mdiag;
+            if( ret != Gtk::RESPONSE_YES ) return 0;
+        }
     }
-    // マルチモードでなく、メインプロセスでもない場合は問い合わせる
-    else if( ! multi_mode && ! iomonitor.is_main_process() )
+    // FIFOに問題がある
+    else
     {
-        Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "JDは既に起動しています。起動しますか？",
+        Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( CACHE::path_lock() + "の作成またはオープンに問題があります。起動しますか？",
                                                             false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
         int ret = mdiag->run();
         delete mdiag;
-        if( ret != Gtk::RESPONSE_YES ) return 0;
+        if( ret != Gtk::RESPONSE_YES ) return 1;
     }
+#endif
+
+    /*---------------------------------------------------------------*/
+#ifdef _WIN32
+    // 多重起動の確認
+    HANDLE hJdLock = NULL;
+    hJdLock = CreateSemaphore(NULL, LONG_MAX, LONG_MAX, "JdForWindowsLockObject"); //2147483647
+    if( ! multi_mode )
+    {
+        if( GetLastError() == ERROR_ALREADY_EXISTS )
+        {
+            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "JDは既に起動しています。起動しますか？",
+                                                                false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            int ret = mdiag->run();
+            delete mdiag;
+            if( ret != Gtk::RESPONSE_YES )
+            {
+                CloseHandle( hJdLock );
+                return 0;
+            }
+        }
+    }
+#endif
     /*---------------------------------------------------------------*/
 
     // バックアップファイル復元
     restore_bkup();
 
-    Win_Main = new WinMain( init );
+    Win_Main = new JDWinMain( init, skip_setupdiag );
     if( Win_Main ){
 
         m.run( *Win_Main );
@@ -511,6 +572,12 @@ int main( int argc, char **argv )
 #ifdef USE_XSMP
     xsmp_session_end( &xsmpdata );
 #endif
+#ifdef _WIN32
+    if( hJdLock != NULL )
+    {
+        CloseHandle( hJdLock );
+    }
+#endif
 
     JDLIB::deinit_ssl();
 
