@@ -12,6 +12,7 @@
 
 #include "bbslist/bbslistadmin.h"
 #include "article/articleadmin.h"
+#include "article/articleviewbase.h"
 
 #include <sstream>
 
@@ -45,8 +46,8 @@ std::list< bool > article_locked;
 std::list< std::string > image_urls;
 std::list< bool > image_locked;
 
-std::string items_sidebar_str;
-std::vector< int > items_sidebar;
+std::string items_sidebar_toolbar_str;
+std::vector< int > items_sidebar_toolbar;
 
 std::string items_main_toolbar_str;
 std::vector< int > items_main_toolbar;
@@ -57,12 +58,15 @@ std::vector< int > items_article_toolbar;
 std::string items_board_toolbar_str;
 std::vector< int > items_board_toolbar;
 
-std::string items_board_str;
-std::vector< int > items_board;
+std::string items_board_col_str;
+std::vector< int > items_board_col;
 
 std::string items_msg_toolbar_str;
 std::vector< int > items_msg_toolbar;
 
+std::string items_article_menu_str;
+std::vector< int > items_article_menu;
+
 int board_col_mark;
 int board_col_id;
 int board_col_subject;
@@ -146,7 +150,80 @@ std::string dir_select_favorite;
 /////////////////////////////////////
 
 
-// 項目名 -> 番号変換
+// ツールバー等の項目名 -> ID 変換
+const int SESSION::parse_item( const std::string& item_name )
+{
+    int item = ITEM_END;
+
+    if( item_name == ITEM_NAME_BBSLISTVIEW ) item = ITEM_BBSLISTVIEW;
+    else if( item_name == ITEM_NAME_FAVORITEVIEW ) item = ITEM_FAVORITEVIEW;
+    else if( item_name == ITEM_NAME_BOARDVIEW ) item = ITEM_BOARDVIEW;
+    else if( item_name == ITEM_NAME_HISTVIEW ) item = ITEM_HISTVIEW;
+    else if( item_name == ITEM_NAME_HIST_BOARDVIEW ) item = ITEM_HIST_BOARDVIEW;
+    else if( item_name == ITEM_NAME_HIST_CLOSEVIEW ) item = ITEM_HIST_CLOSEVIEW;
+    else if( item_name == ITEM_NAME_ARTICLEVIEW ) item = ITEM_ARTICLEVIEW;
+    else if( item_name == ITEM_NAME_IMAGEVIEW ) item = ITEM_IMAGEVIEW;
+    else if( item_name == ITEM_NAME_URL ) item = ITEM_URL;
+    else if( item_name == ITEM_NAME_GO ) item = ITEM_GO;
+    else if( item_name == ITEM_NAME_SEPARATOR ) item = ITEM_SEPARATOR;
+
+    else if( item_name == ITEM_NAME_MARK ) item = ITEM_MARK;
+    else if( item_name == ITEM_NAME_ID ) item = ITEM_ID;
+    else if( item_name == ITEM_NAME_NAME ) item = ITEM_NAME;
+    else if( item_name == ITEM_NAME_RES ) item = ITEM_RES;
+    else if( item_name == ITEM_NAME_LOAD ) item = ITEM_LOAD;
+    else if( item_name == ITEM_NAME_NEW ) item = ITEM_NEW;
+    else if( item_name == ITEM_NAME_SINCE ) item = ITEM_SINCE;
+    else if( item_name == ITEM_NAME_LASTWRITE ) item = ITEM_LASTWRITE;
+    else if( item_name == ITEM_NAME_SPEED ) item = ITEM_SPEED;
+
+    else if( item_name == ITEM_NAME_WRITEMSG ) item = ITEM_WRITEMSG;
+    else if( item_name == ITEM_NAME_OPENBOARD ) item = ITEM_OPENBOARD;
+    else if( item_name == ITEM_NAME_SEARCH ) item = ITEM_SEARCH;
+    else if( item_name == ITEM_NAME_DRAWOUT ) item = ITEM_DRAWOUT;
+    else if( item_name == ITEM_NAME_RELOAD ) item = ITEM_RELOAD;
+    else if( item_name == ITEM_NAME_STOPLOADING ) item = ITEM_STOPLOADING;
+    else if( item_name == ITEM_NAME_FAVORITE ) item = ITEM_FAVORITE;
+    else if( item_name == ITEM_NAME_CHECK_UPDATE_ROOT ) item = ITEM_CHECK_UPDATE_ROOT;
+    else if( item_name == ITEM_NAME_CHECK_UPDATE_OPEN_ROOT ) item = ITEM_CHECK_UPDATE_OPEN_ROOT;
+    else if( item_name == ITEM_NAME_COPY ) item = ITEM_COPY;
+    else if( item_name == ITEM_NAME_COPY_URL ) item = ITEM_COPY_URL;
+    else if( item_name == ITEM_NAME_COPY_TITLE_URL ) item = ITEM_COPY_TITLE_URL;
+    else if( item_name == ITEM_NAME_COPY_TITLE_URL_THREAD ) item = ITEM_COPY_TITLE_URL_THREAD;
+    else if( item_name == ITEM_NAME_DELETE ) item = ITEM_DELETE;
+    else if( item_name == ITEM_NAME_QUIT ) item = ITEM_QUIT;
+    else if( item_name == ITEM_NAME_PREVVIEW ) item = ITEM_PREVVIEW;
+    else if( item_name == ITEM_NAME_NEXTVIEW ) item = ITEM_NEXTVIEW;
+    else if( item_name == ITEM_NAME_LOCK ) item = ITEM_LOCK;
+    else if( item_name == ITEM_NAME_LIVE ) item = ITEM_LIVE;
+
+    else if( item_name == ITEM_NAME_NEWARTICLE ) item = ITEM_NEWARTICLE;
+    else if( item_name == ITEM_NAME_SEARCHBOX ) item = ITEM_SEARCHBOX;
+    else if( item_name == ITEM_NAME_SEARCH_NEXT ) item = ITEM_SEARCH_NEXT;
+    else if( item_name == ITEM_NAME_SEARCH_PREV ) item = ITEM_SEARCH_PREV;
+
+    else if( item_name == ITEM_NAME_INSERTTEXT ) item = ITEM_INSERTTEXT;
+    else if( item_name == ITEM_NAME_LOCK_MESSAGE ) item = ITEM_LOCK_MESSAGE;
+    else if( item_name == ITEM_NAME_PREVIEW ) item = ITEM_PREVIEW;
+
+    else if( item_name == ITEM_NAME_UNDO ) item = ITEM_UNDO;
+    else if( item_name == ITEM_NAME_REDO ) item = ITEM_REDO;
+
+    else if( item_name == ITEM_NAME_NGWORD ) item = ITEM_NGWORD;
+    else if( item_name == ITEM_NAME_ABONE_SELECTION ) item = ITEM_ABONE_SELECTION;
+    else if( item_name == ITEM_NAME_QUOTE_SELECTION ) item = ITEM_QUOTE_SELECTION;
+    else if( item_name == ITEM_NAME_OPEN_BROWSER ) item = ITEM_OPEN_BROWSER;
+    else if( item_name == ITEM_NAME_USER_COMMAND ) item = ITEM_USER_COMMAND;
+    else if( item_name == ITEM_NAME_ETC ) item = ITEM_ETC;
+    else if( item_name == ITEM_NAME_SAVE_DAT ) item = ITEM_SAVE_DAT;
+    else if( item_name == ITEM_NAME_COPY_THREAD_INFO ) item = ITEM_COPY_THREAD_INFO;
+
+    else if( item_name == ITEM_NAME_PREF_THREAD ) item = ITEM_PREF_THREAD;
+
+    return item;
+}
+
+
 std::vector< int > parse_items( const std::string& items_str )
 {
     std::vector< int > items;
@@ -154,51 +231,8 @@ std::vector< int > parse_items( const std::string& items_str )
     std::list< std::string >::const_iterator it = list_order.begin();
     for( ; it != list_order.end(); ++it ){
 
-        if( *it == ITEM_NAME_BBSLISTVIEW ) items.push_back(ITEM_BBSLISTVIEW );
-        if( *it == ITEM_NAME_FAVORITEVIEW ) items.push_back(ITEM_FAVORITEVIEW );
-        if( *it == ITEM_NAME_BOARDVIEW ) items.push_back(ITEM_BOARDVIEW );
-        if( *it == ITEM_NAME_ARTICLEVIEW ) items.push_back(ITEM_ARTICLEVIEW );
-        if( *it == ITEM_NAME_IMAGEVIEW ) items.push_back(ITEM_IMAGEVIEW );
-        if( *it == ITEM_NAME_URL ) items.push_back(ITEM_URL );
-        if( *it == ITEM_NAME_GO ) items.push_back(ITEM_GO );
-        if( *it == ITEM_NAME_SEPARATOR ) items.push_back(ITEM_SEPARATOR );
-
-        if( *it == ITEM_NAME_MARK ) items.push_back(ITEM_MARK );
-        if( *it == ITEM_NAME_ID ) items.push_back(ITEM_ID );
-        if( *it == ITEM_NAME_NAME ) items.push_back(ITEM_NAME );
-        if( *it == ITEM_NAME_RES ) items.push_back(ITEM_RES );
-        if( *it == ITEM_NAME_LOAD ) items.push_back(ITEM_LOAD );
-        if( *it == ITEM_NAME_NEW ) items.push_back(ITEM_NEW );
-        if( *it == ITEM_NAME_SINCE ) items.push_back(ITEM_SINCE );
-        if( *it == ITEM_NAME_LASTWRITE ) items.push_back(ITEM_LASTWRITE );
-        if( *it == ITEM_NAME_SPEED ) items.push_back(ITEM_SPEED );
-
-        if( *it == ITEM_NAME_WRITEMSG ) items.push_back( ITEM_WRITEMSG );
-        if( *it == ITEM_NAME_OPENBOARD ) items.push_back(ITEM_OPENBOARD );
-        if( *it == ITEM_NAME_SEARCH ) items.push_back(ITEM_SEARCH );
-        if( *it == ITEM_NAME_RELOAD ) items.push_back( ITEM_RELOAD );
-        if( *it == ITEM_NAME_STOPLOADING ) items.push_back( ITEM_STOPLOADING );
-        if( *it == ITEM_NAME_FAVORITE ) items.push_back( ITEM_FAVORITE );
-        if( *it == ITEM_NAME_CHECK_UPDATE_ROOT ) items.push_back( ITEM_CHECK_UPDATE_ROOT );
-        if( *it == ITEM_NAME_CHECK_UPDATE_OPEN_ROOT ) items.push_back( ITEM_CHECK_UPDATE_OPEN_ROOT );
-        if( *it == ITEM_NAME_DELETE ) items.push_back( ITEM_DELETE );
-        if( *it == ITEM_NAME_QUIT ) items.push_back( ITEM_QUIT );
-        if( *it == ITEM_NAME_PREVVIEW ) items.push_back( ITEM_PREVVIEW );
-        if( *it == ITEM_NAME_NEXTVIEW ) items.push_back( ITEM_NEXTVIEW );
-        if( *it == ITEM_NAME_LOCK ) items.push_back( ITEM_LOCK );
-        if( *it == ITEM_NAME_LIVE ) items.push_back( ITEM_LIVE );
-
-        if( *it == ITEM_NAME_NEWARTICLE ) items.push_back( ITEM_NEWARTICLE );
-        if( *it == ITEM_NAME_SEARCHBOX ) items.push_back( ITEM_SEARCHBOX );
-        if( *it == ITEM_NAME_SEARCH_NEXT ) items.push_back( ITEM_SEARCH_NEXT );
-        if( *it == ITEM_NAME_SEARCH_PREV ) items.push_back( ITEM_SEARCH_PREV );
-
-        if( *it == ITEM_NAME_INSERTTEXT ) items.push_back( ITEM_INSERTTEXT );
-        if( *it == ITEM_NAME_LOCK_MESSAGE ) items.push_back( ITEM_LOCK_MESSAGE );
-        if( *it == ITEM_NAME_PREVIEW ) items.push_back( ITEM_PREVIEW );
-
-        if( *it == ITEM_NAME_UNDO ) items.push_back( ITEM_UNDO );
-        if( *it == ITEM_NAME_REDO ) items.push_back( ITEM_REDO );
+        const int item = SESSION::parse_item( *it );
+        if( item != ITEM_END ) items.push_back( item );
     }
     items.push_back( ITEM_END );
 
@@ -302,75 +336,34 @@ void SESSION::init_session()
     read_list_urls( cf, "article_urls", "article_locked", article_urls, article_locked );
     read_list_urls( cf, "image_urls", "image_locked", image_urls, image_locked );
 
-    items_sidebar_str = cf.get_option_str( "items_sidebar",
-                                 ITEM_NAME_SEARCHBOX + std::string ( " " ) +
-                                 ITEM_NAME_SEARCH_NEXT + std::string ( " " ) +
-                                 ITEM_NAME_SEARCH_PREV + std::string ( " " ) );
-
-    items_sidebar =  parse_items( items_sidebar_str );
-
-    items_main_toolbar_str = cf.get_option_str( "items_main_toolbar",
-                                 ITEM_NAME_BBSLISTVIEW + std::string ( " " ) +
-                                 ITEM_NAME_FAVORITEVIEW + std::string ( " " ) +
-                                 ITEM_NAME_BOARDVIEW + std::string ( " " ) +
-                                 ITEM_NAME_ARTICLEVIEW + std::string ( " " ) +
-                                 ITEM_NAME_IMAGEVIEW + std::string ( " " ) +
-                                 ITEM_NAME_SEPARATOR + std::string ( " " ) +
-                                 ITEM_NAME_URL + std::string ( " " ) +
-                                 ITEM_NAME_GO + std::string ( " " ) );
+    // サイドバーのツールバー項目
+    items_sidebar_toolbar_str = cf.get_option_str( "items_sidebar", get_items_sidebar_toolbar_default_str() );
+    items_sidebar_toolbar =  parse_items( items_sidebar_toolbar_str );
 
+    // メインツールバーの項目
+    items_main_toolbar_str = cf.get_option_str( "items_main_toolbar", get_items_main_toolbar_default_str() );
     items_main_toolbar =  parse_items( items_main_toolbar_str );
 
-    items_article_toolbar_str = cf.get_option_str( "items_article_toolbar",
-                                 ITEM_NAME_WRITEMSG + std::string ( " " ) +
-                                 ITEM_NAME_OPENBOARD + std::string ( " " ) +
-                                 ITEM_NAME_NAME + std::string ( " " ) +
-                                 ITEM_NAME_SEARCH + std::string ( " " ) +
-                                 ITEM_NAME_RELOAD + std::string ( " " ) +
-                                 ITEM_NAME_STOPLOADING + std::string ( " " ) +
-                                 ITEM_NAME_FAVORITE + std::string ( " " ) +
-                                 ITEM_NAME_DELETE + std::string ( " " ) +
-                                 ITEM_NAME_QUIT + std::string ( " " ) );
-
+    // スレビューのツールバーの項目
+    items_article_toolbar_str = cf.get_option_str( "items_article_toolbar", get_items_article_toolbar_default_str() );
     items_article_toolbar =  parse_items( items_article_toolbar_str );
 
-    items_board_toolbar_str = cf.get_option_str( "items_board_toolbar",
-                                 ITEM_NAME_NEWARTICLE + std::string ( " " ) +
-                                 ITEM_NAME_SEARCHBOX + std::string ( " " ) +
-                                 ITEM_NAME_SEARCH_NEXT + std::string ( " " ) +
-                                 ITEM_NAME_SEARCH_PREV + std::string ( " " ) +
-                                 ITEM_NAME_RELOAD + std::string ( " " ) +
-                                 ITEM_NAME_STOPLOADING + std::string ( " " ) +
-                                 ITEM_NAME_FAVORITE + std::string ( " " ) +
-                                 ITEM_NAME_DELETE + std::string ( " " ) +
-                                 ITEM_NAME_QUIT + std::string ( " " ) );
-
+    // スレ一覧のツールバー項目
+    items_board_toolbar_str = cf.get_option_str( "items_board_toolbar", get_items_board_toolbar_default_str() );
     items_board_toolbar =  parse_items( items_board_toolbar_str );
 
-    items_board_str = cf.get_option_str( "items_board",
-                                 ITEM_NAME_MARK + std::string ( " " ) +
-                                 ITEM_NAME_ID + std::string ( " " ) +
-                                 ITEM_NAME_NAME + std::string ( " " ) +
-                                 ITEM_NAME_RES + std::string ( " " ) +
-                                 ITEM_NAME_LOAD + std::string ( " " ) +
-                                 ITEM_NAME_NEW + std::string ( " " ) +
-                                 ITEM_NAME_SINCE + std::string ( " " ) +
-                                 ITEM_NAME_LASTWRITE + std::string ( " " ) +
-                                 ITEM_NAME_SPEED + std::string ( " " ) );
-
-    items_board =  parse_items( items_board_str );
-
-    items_msg_toolbar_str = cf.get_option_str( "items_msg_toolbar",
-                                 ITEM_NAME_PREVIEW + std::string ( " " ) +
-                                 ITEM_NAME_WRITEMSG+ std::string ( " " ) +
-                                 ITEM_NAME_NAME + std::string ( " " ) +
-                                 ITEM_NAME_UNDO + std::string ( " " ) +
-                                 ITEM_NAME_INSERTTEXT + std::string ( " " ) +
-                                 ITEM_NAME_LOCK_MESSAGE + std::string ( " " ) +
-                                 ITEM_NAME_QUIT + std::string ( " " ) );
-
+    // 書き込みビューのツールバー項目
+    items_msg_toolbar_str = cf.get_option_str( "items_msg_toolbar", get_items_msg_toolbar_default_str() );
     items_msg_toolbar =  parse_items( items_msg_toolbar_str );
 
+    // スレ一覧の列項目
+    items_board_col_str = cf.get_option_str( "items_board", get_items_board_col_default_str() );
+    items_board_col =  parse_items( items_board_col_str );
+
+    // スレビューのコンテキストメニュー項目
+    items_article_menu_str = cf.get_option_str( "items_article_menu", get_items_article_menu_default_str() );
+    items_article_menu =  parse_items( items_article_menu_str );
+
     // board ビューの列幅
     board_col_mark = cf.get_option_int( "col_mark", 30, 4, 8192 );
     board_col_id = cf.get_option_int( "col_id", 45, 4, 8192 );
@@ -560,12 +553,13 @@ void SESSION::save_session()
         << "image_urls = " << str_image_urls << std::endl
         << "image_locked = " << str_image_locked << std::endl
 
-        << "items_sidebar = " << items_sidebar_str << std::endl
+        << "items_sidebar = " << items_sidebar_toolbar_str << std::endl
         << "items_main_toolbar = " << items_main_toolbar_str << std::endl
         << "items_article_toolbar = " << items_article_toolbar_str << std::endl
         << "items_board_toolbar = " << items_board_toolbar_str << std::endl
-        << "items_board = " << items_board_str << std::endl
         << "items_msg_toolbar = " << items_msg_toolbar_str << std::endl
+        << "items_board = " << items_board_col_str << std::endl
+        << "items_article_menu = " << items_article_menu_str << std::endl
 
         << "col_mark = " << board_col_mark << std::endl
         << "col_id = " << board_col_id << std::endl
@@ -794,16 +788,36 @@ const std::list< bool >& SESSION::get_image_locked(){ return image_locked; }
 void SESSION::set_image_locked( const std::list< bool >& locked ){ image_locked = locked; }
 
 // サイドバーのツールバーの項目
-const std::string& SESSION::get_items_sidebar_str(){ return items_sidebar_str; }
-void SESSION::set_items_sidebar_str( const std::string& items_str )
+const std::string& SESSION::get_items_sidebar_toolbar_str(){ return items_sidebar_toolbar_str; }
+const std::string SESSION::get_items_sidebar_toolbar_default_str()
 {
-    items_sidebar_str = items_str;
-    items_sidebar = parse_items( items_sidebar_str );
+    return
+    ITEM_NAME_SEARCHBOX + std::string ( " " ) +
+    ITEM_NAME_SEARCH_NEXT + std::string ( " " ) +
+    ITEM_NAME_SEARCH_PREV;
+
 }
-const int SESSION::get_item_sidebar( const int num ){ return items_sidebar[ num ]; }
+void SESSION::set_items_sidebar_toolbar_str( const std::string& items_str )
+{
+    items_sidebar_toolbar_str = items_str;
+    items_sidebar_toolbar = parse_items( items_sidebar_toolbar_str );
+}
+const int SESSION::get_item_sidebar_toolbar( const int num ){ return items_sidebar_toolbar[ num ]; }
 
 // メインツールバーの項目
 const std::string& SESSION::get_items_main_toolbar_str(){ return items_main_toolbar_str; }
+const std::string SESSION::get_items_main_toolbar_default_str()
+{
+    return
+    ITEM_NAME_BBSLISTVIEW + std::string ( " " ) +
+    ITEM_NAME_FAVORITEVIEW + std::string ( " " ) +
+    ITEM_NAME_BOARDVIEW + std::string ( " " ) +
+    ITEM_NAME_ARTICLEVIEW + std::string ( " " ) +
+    ITEM_NAME_IMAGEVIEW + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_URL + std::string ( " " ) +
+    ITEM_NAME_GO;
+}
 void SESSION::set_items_main_toolbar_str( const std::string& items_str )
 {
     items_main_toolbar_str = items_str;
@@ -813,6 +827,19 @@ const int SESSION::get_item_main_toolbar( const int num ){ return items_main_too
 
 // スレビューのツールバーの項目
 const std::string& SESSION::get_items_article_toolbar_str(){ return items_article_toolbar_str; }
+const std::string SESSION::get_items_article_toolbar_default_str()
+{
+    return
+    ITEM_NAME_WRITEMSG + std::string ( " " ) +
+    ITEM_NAME_OPENBOARD + std::string ( " " ) +
+    ITEM_NAME_NAME + std::string ( " " ) +
+    ITEM_NAME_SEARCH + std::string ( " " ) +
+    ITEM_NAME_RELOAD + std::string ( " " ) +
+    ITEM_NAME_STOPLOADING + std::string ( " " ) +
+    ITEM_NAME_FAVORITE + std::string ( " " ) +
+    ITEM_NAME_DELETE + std::string ( " " ) +
+    ITEM_NAME_QUIT;
+}
 void SESSION::set_items_article_toolbar_str( const std::string& items_str )
 {
     items_article_toolbar_str = items_str;
@@ -822,6 +849,19 @@ const int SESSION::get_item_article_toolbar( const int num ){ return items_artic
 
 // スレ一覧のツールバー項目
 const std::string& SESSION::get_items_board_toolbar_str(){ return items_board_toolbar_str; }
+const std::string SESSION::get_items_board_toolbar_default_str()
+{
+    return
+    ITEM_NAME_NEWARTICLE + std::string ( " " ) +
+    ITEM_NAME_SEARCHBOX + std::string ( " " ) +
+    ITEM_NAME_SEARCH_NEXT + std::string ( " " ) +
+    ITEM_NAME_SEARCH_PREV + std::string ( " " ) +
+    ITEM_NAME_RELOAD + std::string ( " " ) +
+    ITEM_NAME_STOPLOADING + std::string ( " " ) +
+    ITEM_NAME_FAVORITE + std::string ( " " ) +
+    ITEM_NAME_DELETE + std::string ( " " ) +
+    ITEM_NAME_QUIT;
+}
 void SESSION::set_items_board_toolbar_str( const std::string& items_str )
 {
     items_board_toolbar_str = items_str;
@@ -829,17 +869,19 @@ void SESSION::set_items_board_toolbar_str( const std::string& items_str )
 }
 const int SESSION::get_item_board_toolbar( const int num ){ return items_board_toolbar[ num ]; }
 
-// スレ一覧の項目
-const std::string& SESSION::get_items_board_str(){ return items_board_str; }
-void SESSION::set_items_board_str( const std::string& items_str )
-{
-    items_board_str = items_str;
-    items_board = parse_items( items_board_str );
-}
-const int SESSION::get_item_board( const int num ){ return items_board[ num ]; }
-
 // 書き込みビューのツールバー項目
 const std::string& SESSION::get_items_msg_toolbar_str(){ return items_msg_toolbar_str; }
+const std::string SESSION::get_items_msg_toolbar_default_str()
+{
+    return
+    ITEM_NAME_PREVIEW + std::string ( " " ) +
+    ITEM_NAME_WRITEMSG+ std::string ( " " ) +
+    ITEM_NAME_NAME + std::string ( " " ) +
+    ITEM_NAME_UNDO + std::string ( " " ) +
+    ITEM_NAME_INSERTTEXT + std::string ( " " ) +
+    ITEM_NAME_LOCK_MESSAGE + std::string ( " " ) +
+    ITEM_NAME_QUIT;
+}
 void SESSION::set_items_msg_toolbar_str( const std::string& items_str )
 {
     items_msg_toolbar_str = items_str;
@@ -847,6 +889,56 @@ void SESSION::set_items_msg_toolbar_str( const std::string& items_str )
 }
 const int SESSION::get_item_msg_toolbar( const int num ){ return items_msg_toolbar[ num ]; }
 
+// スレ一覧の列項目
+const std::string& SESSION::get_items_board_col_str(){ return items_board_col_str; }
+const std::string SESSION::get_items_board_col_default_str()
+{
+    return
+    ITEM_NAME_MARK + std::string ( " " ) +
+    ITEM_NAME_ID + std::string ( " " ) +
+    ITEM_NAME_NAME + std::string ( " " ) +
+    ITEM_NAME_RES + std::string ( " " ) +
+    ITEM_NAME_LOAD + std::string ( " " ) +
+    ITEM_NAME_NEW + std::string ( " " ) +
+    ITEM_NAME_SINCE + std::string ( " " ) +
+    ITEM_NAME_LASTWRITE + std::string ( " " ) +
+    ITEM_NAME_SPEED;
+}
+void SESSION::set_items_board_col_str( const std::string& items_str )
+{
+    items_board_col_str = items_str;
+    items_board_col = parse_items( items_board_col_str );
+}
+const int SESSION::get_item_board_col( const int num ){ return items_board_col[ num ]; }
+
+// スレビューのコンテキストメニュー項目
+const std::string& SESSION::get_items_article_menu_str(){ return items_article_menu_str; }
+const std::string SESSION::get_items_article_menu_default_str()
+{
+    return
+    ITEM_NAME_DRAWOUT + std::string ( " " ) +
+    ITEM_NAME_GO + std::string ( " " ) +
+    ITEM_NAME_SEARCH + std::string ( " " ) +
+    ITEM_NAME_NGWORD + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_QUOTE_SELECTION + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_OPEN_BROWSER + std::string ( " " ) +
+    ITEM_NAME_USER_COMMAND + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_COPY_URL + std::string ( " " ) +
+    ITEM_NAME_COPY + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_ETC + std::string ( " " ) +
+    ITEM_NAME_SEPARATOR + std::string ( " " ) +
+    ITEM_NAME_PREF_THREAD;
+}
+void SESSION::set_items_article_menu_str( const std::string& items_str )
+{
+    items_article_menu_str = items_str;
+    items_article_menu = parse_items( items_article_menu_str );
+}
+const int SESSION::get_item_article_menu( const int num ){ return items_article_menu[ num ]; }
 
 // board ビューの列幅
 const int SESSION::col_mark(){ return board_col_mark; }
@@ -860,14 +952,14 @@ const int SESSION::col_write(){ return board_col_write; }
 const int SESSION::col_speed(){ return board_col_speed; }
 
 
-// 現在開いている bbslist のページ
-const int SESSION::get_bbslist_current_page()
+// 現在開いているサイドバーのページ
+const int SESSION::get_sidebar_current_page()
 {
     return BBSLIST::get_admin()->get_current_page();
 }
 
-// 現在開いている bbslist のurl
-const std::string SESSION::get_bbslist_current_url()
+// 現在開いているサイドバーのurl
+const std::string SESSION::get_sidebar_current_url()
 {
     return BBSLIST::get_admin()->get_current_url();
 }
@@ -884,6 +976,21 @@ void SESSION::set_col_write( const int width ){ board_col_write = width; }
 void SESSION::set_col_speed( const int width ){ board_col_speed = width; }
 
 
+// 現在開いているarticle の ARTICLE::DrawAreaBase
+ARTICLE::DrawAreaBase* SESSION::get_base_drawarea()
+{
+    ARTICLE::ArticleViewBase* base_view = NULL;
+    base_view = dynamic_cast< ARTICLE::ArticleViewBase* >( ARTICLE::get_admin()->get_current_view() );
+
+    if( base_view == NULL ) return NULL;
+
+    ARTICLE::DrawAreaBase* base_drawarea = NULL;
+    base_drawarea = base_view->drawarea();
+
+    return base_drawarea;
+}
+
+
 // 現在開いているarticle のurl
 const std::string SESSION::get_article_current_url()
 {
@@ -1026,3 +1133,10 @@ void SESSION::set_dir_select_favorite( const std::string& dir )
 {
     dir_select_favorite = dir;
 }
+
+
+// 各履歴を取得
+void SESSION::get_history( const std::string& url, CORE::DATA_INFO_LIST& info_list )
+{
+    return BBSLIST::get_admin()->get_history( url, info_list );
+}
