@@ -6,6 +6,9 @@
 #ifndef _SESSION_H
 #define _SESSION_H
 
+#include "type.h"
+#include "article/drawareabase.h"
+
 #include <list>
 #include <vector>
 #include <string>
@@ -267,42 +270,57 @@ namespace SESSION
     const std::list< bool >& get_image_locked();
     void set_image_locked( const std::list< bool >& locked );
 
-    // 現在開いている bbslist のページ
-    const int get_bbslist_current_page();
+    // 現在開いているサイドバーのページ
+    const int get_sidebar_current_page();
 
-    // 現在開いている bbslist のurl
-    const std::string get_bbslist_current_url();
+    // 現在開いているサイドバーのurl
+    const std::string get_sidebar_current_url();
+
+    // ツールバー等の項目名 -> ID 変換
+    const int parse_item( const std::string& item_name );
 
     // サイドバーのツールバー項目
-    const std::string& get_items_sidebar_str();
-    void set_items_sidebar_str( const std::string& items );
-    const int get_item_sidebar( const int num );
+    const std::string& get_items_sidebar_toolbar_str();
+    const std::string get_items_sidebar_toolbar_default_str();
+    void set_items_sidebar_toolbar_str( const std::string& items );
+    const int get_item_sidebar_toolbar( const int num );
 
     // メインツールバーの項目
     const std::string& get_items_main_toolbar_str();
+    const std::string get_items_main_toolbar_default_str();
     void set_items_main_toolbar_str( const std::string& items_str );
     const int get_item_main_toolbar( const int num );
 
     // スレビューのツールバーの項目
     const std::string& get_items_article_toolbar_str();
+    const std::string get_items_article_toolbar_default_str();
     void set_items_article_toolbar_str( const std::string& items_str );
     const int get_item_article_toolbar( const int num );
 
     // スレ一覧のツールバー項目
     const std::string& get_items_board_toolbar_str();
+    const std::string get_items_board_toolbar_default_str();
     void set_items_board_toolbar_str( const std::string& items );
     const int get_item_board_toolbar( const int num );
 
-    // スレ一覧の項目
-    const std::string& get_items_board_str();
-    void set_items_board_str( const std::string& items );
-    const int get_item_board( const int num );
-
     // 書き込みビューのツールバー項目
     const std::string& get_items_msg_toolbar_str();
+    const std::string get_items_msg_toolbar_default_str();
     void set_items_msg_toolbar_str( const std::string& items );
     const int get_item_msg_toolbar( const int num );
 
+    // スレ一覧の列項目
+    const std::string& get_items_board_col_str();
+    const std::string get_items_board_col_default_str();
+    void set_items_board_col_str( const std::string& items );
+    const int get_item_board_col( const int num );
+
+    // スレビューのコンテキストメニュー項目
+    const std::string& get_items_article_menu_str();
+    const std::string get_items_article_menu_default_str();
+    void set_items_article_menu_str( const std::string& items_str );
+    const int get_item_article_menu( const int num );
+
     // スレ一覧の列幅
     const int col_mark();
     const int col_id();
@@ -323,6 +341,8 @@ namespace SESSION
     void set_col_write( const int width );
     void set_col_speed( const int width );
 
+    // 現在開いているarticle の ARTICLE::DrawAreaBase
+    ARTICLE::DrawAreaBase* get_base_drawarea();
 
     // 現在開いているarticle のurl
     const std::string get_article_current_url();
@@ -375,6 +395,9 @@ namespace SESSION
     // お気に入り挿入ダイアログで最後に保存したディレクトリ名
     const std::string& get_dir_select_favorite();
     void set_dir_select_favorite( const std::string& dir );
+
+    // 各履歴を取得
+    void get_history( const std::string& url, CORE::DATA_INFO_LIST& info_list );
 }
 
 
