@@ -20,6 +20,7 @@ namespace SKELETON
     class JDWindow;
     class View;
     class DragableNoteBook;
+    class TabSwitchMenu;
 
     class Admin : public Dispatchable
     {
@@ -37,10 +38,12 @@ namespace SKELETON
         Glib::RefPtr< Gtk::UIManager > m_ui_manager;
         int m_clicked_page;
 
-        // 移動サブメニュー用
-        Gtk::Menu* m_move_menu;
-        std::vector< Gtk::MenuItem* > m_vec_movemenu_items;
-        std::vector< bool > m_vec_movemenu_append;
+        // 移動サブメニュー
+        Gtk::MenuItem* m_move_menuitem;
+        TabSwitchMenu* m_move_menu;
+
+        // タブ切り替えメニュー
+        TabSwitchMenu* m_tabswitchmenu;
 
         // view履歴使用
         bool m_use_viewhistory;
@@ -51,7 +54,7 @@ namespace SKELETON
         Admin( const std::string& url );
         virtual ~Admin();
 
-        void setup_menu( const bool enable_checkupdate );
+        void setup_menu();
 
         virtual bool empty();
         const std::string& get_url() const{ return m_url; }
@@ -68,7 +71,7 @@ namespace SKELETON
         virtual int get_tab_nums();
 
         // 含まれているページのURLのリスト取得
-        virtual std::list< std::string > get_URLs();
+        virtual const std::list< std::string > get_URLs();
 
         // Core からのクロック入力。
         // Coreでタイマーをひとつ動かして全体の同期を取るようにしているので
@@ -105,9 +108,20 @@ namespace SKELETON
         virtual int get_current_page();
         std::string get_current_url();
 
+        // urlで指定されるタブがロックされているか
+        const bool is_locked( const std::string& url );
+
         // SIGHUPを受け取ったときの処理
         virtual void shutdown();
 
+        // 指定したページに表示切替え
+        void set_current_page( const int page );
+
+        // フォーカスしてから指定したページに表示切替え
+        void set_current_page_focus( const int page );
+
+        virtual View* get_current_view();
+
     protected:
 
         void set_use_viewhistory( const bool use ){ m_use_viewhistory = use; }
@@ -153,10 +167,17 @@ namespace SKELETON
         virtual void open_view( const COMMAND_ARGS& command );
         virtual void switch_admin() = 0;  // CORE::core_set_command( "switch_*" )　を送る
         virtual void switch_view( const std::string& url );
-        virtual void tab_left();
-        virtual void tab_right();
+
+        // タブ左右移動
+        // updated == true の時は更新されたタブに移動
+        virtual void tab_left( const bool updated );
+        virtual void tab_right( const bool updated );
+
+        virtual void tab_num( const std::string& str_num );
         virtual void tab_head();
+        void tab_head_focus();
         virtual void tab_tail();
+        void tab_tail_focus();
         virtual void redraw_view( const std::string& url );
         virtual void redraw_current_view();
         virtual void relayout_current_view();
@@ -186,18 +207,19 @@ namespace SKELETON
         // オートリロードのモード設定
         virtual bool set_autoreload_mode( const std::string& url, int mode, int sec );
 
-        // D&D 処理
-        // 派生クラス別にD&Dの処理を行う
-        virtual void slot_drag_begin( int page ) = 0;
-        virtual void slot_drag_end() = 0;
+        // タブをお気に入りにドロップした時にお気に入りがデータ送信を要求してきた
+        virtual void slot_drag_data_get( Gtk::SelectionData& selection_data, const int page ) = 0;
 
-        void open_list( const std::string& str_list );
-        virtual COMMAND_ARGS get_open_list_args( const std::string& url ){ return COMMAND_ARGS(); }
+        void open_list( const COMMAND_ARGS& command_list );
+        virtual COMMAND_ARGS get_open_list_args( const std::string& url, const COMMAND_ARGS& command_list ){ return COMMAND_ARGS(); }
         virtual View* create_view( const COMMAND_ARGS& command ){ return NULL; };
         virtual View* get_view( const std::string& url );
+
+        // url を含むビュークラスをリストで取得 ( url と一致するビューでは無い )
         std::list< View* > get_list_view( const std::string& url );
+
+        // 全てのビュークラスをリストで取得
         std::list< View* > get_list_view();
-        virtual View* get_current_view();
 
         // ツールバー
         virtual void show_toolbar(){}
@@ -209,30 +231,36 @@ namespace SKELETON
         virtual void close_searchbar(){}
 
         // タブの更新チェック
-        void check_update_all_tabs( const int from_page );
+        void check_update_all_tabs( const int from_page, const bool open );
 
         // タブの再読み込み
         void reload_all_tabs();
         void reload_all_tabs( const int from_page );
 
-        // 指定したページに表示切替え
-        virtual void set_current_page( int page );
-
         // notebookのタブが切り替わったときに呼ばれるslot
         void slot_switch_page( GtkNotebookPage*, guint page );
 
-        // タブをクリック
-        virtual void slot_tab_click( int page );
+        // タブをクリックした
+        void slot_tab_clicked( const int page );
+
+        // タブの上でホイールを回した
+        void slot_tab_scrolled( GdkEventScroll* event );
 
         // タブを閉じる
-        virtual void slot_tab_close( int page );
+        void slot_tab_close( const int page );
 
         // タブ再読み込み
-        virtual void slot_tab_reload( int page );
+        void slot_tab_reload( const int page );
 
         // タブメニュー表示
         virtual void slot_tab_menu( int page, int x, int y );
 
+        // タブ切り替えメニュー表示
+        void slot_show_tabswitchmenu();
+
+        // タブ切り替えメニューの位置決め
+        void slot_popup_pos( int& x, int& y, bool& push_in );
+
         // 右クリックメニュー
         virtual void slot_close_tab();
         virtual void slot_lock();
@@ -272,6 +300,8 @@ namespace SKELETON
 
       private:
 
+        void slot_popupmenu_deactivate();
+
         bool back_forward_viewhistory( const std::string& url, const bool back, const int count );
 
         // 移転などでviewのurlを更新
