@@ -6,20 +6,25 @@
 #include "editview.h"
 #include "aamenu.h"
 
-#include "controlid.h"
-#include "controlutil.h"
+#include "control/controlid.h"
+#include "control/controlutil.h"
+
 #include "aamanager.h"
+#include "environment.h"
 #include "session.h"
-#include "jdversion.h"
 
 #include "jdlib/miscutil.h"
 #include "config/globalconf.h"
 
-#include <sstream>
-
+#include "gtk/gtktextview.h"
 
 using namespace SKELETON;
 
+enum
+{
+    MIN_AAMENU_LINES = 12
+};
+
 
 EditTextView::EditTextView() :
     Gtk::TextView(),
@@ -307,11 +312,49 @@ bool EditTextView::on_button_press_event( GdkEventButton* event )
 //
 bool EditTextView::on_key_press_event( GdkEventKey* event )
 {
+#ifdef _DEBUG    
+    std::cout << "EditTextView::on_key_press_event key = " << event->keyval << std::endl;
+#endif
+
     bool cancel_event = false;
     m_delete_pushed = false;
     if( event->keyval == GDK_Delete ) m_delete_pushed = true;
 
-    switch( m_control.key_press( event ) ){
+    const int controlid = m_control.key_press( event );
+
+    switch( controlid ){
+
+        case CONTROL::ExecWrite:
+        case CONTROL::CancelWrite:
+        case CONTROL::FocusWrite:
+        case CONTROL::TabLeft:
+        case CONTROL::TabRight:
+        case CONTROL::TabLeftUpdated:
+        case CONTROL::TabRightUpdated:
+        case CONTROL::HomeEdit:
+        case CONTROL::EndEdit:
+        case CONTROL::UpEdit:
+        case CONTROL::DownEdit:
+        case CONTROL::RightEdit:
+        case CONTROL::LeftEdit:
+        case CONTROL::DeleteEdit:
+        case CONTROL::BackspEdit:
+        case CONTROL::UndoEdit:
+        case CONTROL::InputAA:
+        {
+            GtkTextView *textview = gobj();
+            if( gtk_im_context_filter_keypress( textview->im_context, event ) )
+            {
+#ifdef _DEBUG    
+                std::cout << "gtk_im_context_filter_keypress\n";
+#endif
+                textview->need_im_reset = TRUE;
+                return true;
+            }
+        }
+    }
+
+    switch( controlid ){
 
         // MessageViewでショートカットで書き込むと文字が挿入されてしまうので
         // キャンセルする
@@ -347,6 +390,10 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
 
 bool EditTextView::on_key_release_event( GdkEventKey* event )
 {
+#ifdef _DEBUG    
+    std::cout << "EditTextView::on_key_release_event key = " << event->keyval << std::endl;
+#endif
+
     bool cancel_event = false;
 
     switch( m_control.key_press( event ) ){
@@ -406,6 +453,11 @@ void EditTextView::on_populate_popup( Gtk::Menu* menu )
     menuitem->signal_button_press_event().connect( sigc::mem_fun( *this, &EditTextView::slot_write_jdinfo ) );
     menu->prepend( *menuitem );
 
+    // 変換(スペース⇔&nbsp;)
+    menuitem = Gtk::manage( new Gtk::MenuItem( "変換(スペース⇔&nbsp;)" ) );
+    menuitem->signal_button_press_event().connect( sigc::mem_fun( *this, &EditTextView::slot_convert_space ) );
+    menu->prepend( *menuitem );
+
     // クリップボードから引用
     menuitem = Gtk::manage( new Gtk::MenuItem( "クリップボードから引用" ) );
     menuitem->signal_button_press_event().connect( sigc::mem_fun( *this, &EditTextView::slot_quote_clipboard ) );
@@ -418,10 +470,7 @@ void EditTextView::on_populate_popup( Gtk::Menu* menu )
     // AA入力メニュー追加
     if( CORE::get_aamanager()->get_size() ){
 
-        std::string label = CONTROL::get_label( CONTROL::InputAA );
-        std::string motion = CONTROL::get_motion( CONTROL::InputAA );
-
-        menuitem = Gtk::manage( new Gtk::MenuItem( label + "  " + motion ) );
+        menuitem = Gtk::manage( new Gtk::MenuItem( CONTROL::get_label_motions( CONTROL::InputAA ) ) );
         menuitem->signal_button_press_event().connect( sigc::mem_fun( *this, &EditTextView::slot_select_aamenu ) );
         menu->prepend( *menuitem );
     }
@@ -460,50 +509,57 @@ bool EditTextView::slot_quote_clipboard( GdkEventButton* event )
 }
 
 
+//
+// 変換(スペース⇔&nbsp;)
+//
+bool EditTextView::slot_convert_space( GdkEventButton* event )
+{
+    Glib::RefPtr< Gtk::TextBuffer > buffer = get_buffer();
+    std::string text = buffer->get_text();
+    std::string converted;
+
+    // &nbsp;が含まれていたらスペースに変換する
+    if( text.find( "&nbsp;", 0 ) != std::string::npos )
+    {
+        converted = MISC::replace_str( text, "&nbsp;", " " );
+    }
+    else
+    {
+        size_t rpos = std::string::npos;
+        size_t nlpos = std::string::npos;
+
+        // 改行前のスペースを取り除く
+        while( ( nlpos = text.rfind( "\n", rpos ) ) != std::string::npos )
+        {
+            if( nlpos == 0 ) break;
+            rpos = nlpos;
+            while( text[ rpos - 1 ] == ' ' ) rpos--;
+            text.erase( rpos, nlpos - rpos );
+            rpos--;
+        }
+
+        // 最後のスペースを取り除く
+        rpos = text.length();
+        while( text[ rpos - 1 ] == ' ' ) rpos--;
+        text.erase( rpos, std::string::npos );
+
+        converted = MISC::replace_str( text, " ", "&nbsp;" );
+    }
+
+    buffer->set_text( converted );
+
+    return true;
+}
+
+
 //
 // JDの動作環境を記入
 //
 bool EditTextView::slot_write_jdinfo( GdkEventButton* event )
 {
-    std::stringstream jd_info;
+    std::string jdinfo = ENVIRONMENT::get_jdinfo();
 
-    // バージョンを取得
-    const std::string version = JDVERSIONSTR;
-
-    // ディストリビューション名を取得
-    const std::string distribution = SESSION::get_distribution();
-
-    // デスクトップ環境を取得( 環境変数から判別可能の場合 )
-    std::string desktop_environment;
-    switch( SESSION::get_wm() )
-    {
-        case SESSION::WM_GNOME : desktop_environment = "GNOME"; break;
-        case SESSION::WM_XFCE  : desktop_environment = "XFCE";  break;
-        case SESSION::WM_KDE   : desktop_environment = "KDE";   break;
-    }
-
-    // その他
-    std::string other;
-
-    // $LANG が ja_JP.UTF-8 でない場合は"その他"に追加する。
-    std::string lang;
-    if( getenv( "LANG" ) ) lang = std::string( getenv( "LANG" ) );
-    if( lang.empty() ) other.append( "LANG 未定義" );
-    else if( lang != "ja_JP.utf8" && lang != "ja_JP.UTF-8" ) other.append( "LANG = " + lang );
-
-    jd_info <<
-    "[バージョン] " << version << "\n" <<
-//#ifdef REPOSITORY_URL
-//    "[リポジトリ ] " << REPOSITORY_URL << "\n" <<
-//#endif
-    "[ディストリ ] " << distribution << "\n" <<
-    "[パッケージ] " << "バイナリ/ソース( <配布元> )" << "\n" <<
-    "[ DE／WM ] " << desktop_environment << "\n" <<
-    "[gtkmm-2.4] " << GTKMM_VERSION << "\n" <<
-    "[glibmm-2.4] " << GLIBMM_VERSION << "\n" <<
-    "[ そ の 他 ] " << other << "\n";
-
-    insert_str( jd_info.str(), false );
+    insert_str( jdinfo, false );
 
     return true;
 }
@@ -569,11 +625,18 @@ void EditTextView::show_aalist_popup()
 //
 void EditTextView::slot_popup_aamenu_pos( int& x, int& y, bool& push_in )
 {
-    Gdk::Rectangle rect = get_cursor_root_origin();
+    push_in = false;
+
+    const Gdk::Rectangle rect = get_cursor_root_origin();
+    const int line_height = rect.get_height();
+    const int sh = get_screen()->get_height();
+    const int min_height = MIN( CORE::get_aamanager()->get_size(), MIN_AAMENU_LINES ) * line_height;
 
     x = rect.get_x();
-    y = rect.get_y() + rect.get_height();
-    push_in = false;
+    y = rect.get_y() + line_height;
+
+    // 最低でも MIN_AAMENU_LINES 行よりも表示領域が高くなるようにする
+    if( y + min_height > sh ) y = sh - min_height;
 }
 
 
