@@ -36,7 +36,8 @@ using namespace SKELETON;
 ToolBar::ToolBar( Admin* admin )
     : m_admin( admin ),
       m_enable_slot( true ),
-      m_toolbar_shown( false ),
+      m_buttonbar_shown( false ),
+      m_buttonbar_packed( false ),
 
       m_tool_label( NULL ),
       m_ebox_label( NULL ),
@@ -44,6 +45,7 @@ ToolBar::ToolBar( Admin* admin )
 
       m_searchbar( NULL ),
       m_searchbar_shown( false ),
+      m_searchbar_packed( false ),
       m_button_open_searchbar( NULL ),
       m_button_close_searchbar( NULL ),
       m_button_up_search( NULL ),
@@ -61,6 +63,8 @@ ToolBar::ToolBar( Admin* admin )
       m_button_close( NULL ),
       m_button_delete( NULL ),
       m_button_favorite( NULL ),
+      m_button_undo( NULL ),
+      m_button_redo( NULL ),
       m_button_lock( NULL ),
 
       m_button_back( NULL ),
@@ -83,7 +87,15 @@ void ToolBar::set_url( const std::string& url )
 }
 
 
+const bool ToolBar::is_empty()
+{
+    return ( ! m_buttonbar.get_children().size() );
+}
+
+
+//
 // タブが切り替わった時にDragableNoteBook::set_current_toolbar()から呼び出される( Viewの情報を取得する )
+//
 // virtual
 void ToolBar::set_view( SKELETON::View* view )
 {
@@ -116,37 +128,61 @@ void ToolBar::set_view( SKELETON::View* view )
 }
 
 
-bool ToolBar::is_empty()
-{
-    return ( ! m_buttonbar.get_children().size() );
-}
-
-
-// ツールバーを表示
+//
+// タブが切り替わった時にDragableNoteBookから呼び出される( ツールバーを表示する )
+//
+// gtk+-2.4 辺りの古い gtk では、スレビューなどツールバーの複数が複数ある場合に
+// 最初からボタンバーを pack するとボタンが押せなくなる症状があったので、実際に
+// ツールバーが表示されるまでpackしないようにした
+//
 void ToolBar::show_toolbar()
 {
-    if( ! m_toolbar_shown ){
-
-        if( m_searchbar && m_searchbar_shown ) remove( *m_searchbar );
+    // ボタンバーのpack
+    if( m_buttonbar_shown && ! m_buttonbar_packed ){
 
+        if( m_searchbar_packed ) remove( *m_searchbar );
         pack_start( m_buttonbar, Gtk::PACK_SHRINK );
-        if( m_searchbar && m_searchbar_shown ) pack_start( *m_searchbar, Gtk::PACK_SHRINK );
+        if( m_searchbar_packed ) pack_start( *m_searchbar, Gtk::PACK_SHRINK );
 
         show_all_children();
         set_relief();
-        m_toolbar_shown = true;
+
+        m_buttonbar_packed = true;
+    }
+
+    // 検索バーのpack
+    if( m_searchbar_shown && ! m_searchbar_packed ){
+
+        pack_start( *m_searchbar, Gtk::PACK_SHRINK );
+
+        show_all_children();
+        set_relief();
+
+        m_searchbar_packed = true;
     }
 }
 
 
-// ツールバーを隠す
-void ToolBar::hide_toolbar()
+// ボタンバー表示
+void ToolBar::open_buttonbar()
 {
-    if( m_toolbar_shown ){
+    // フラグだけ立てて実際に pack するのは show_toolbar() の中
+    // 何故そんな面倒な事をしているかは show_toolbar() の説明を参照
+    m_buttonbar_shown = true;
+}
+
+
+// ボタンバーを隠す
+void ToolBar::close_buttonbar()
+{
+    m_buttonbar_shown = false;
+
+    if( m_buttonbar_packed ){
 
         remove( m_buttonbar );
+
         show_all_children();
-        m_toolbar_shown = false;
+        m_buttonbar_packed = false;
     }
 }
 
@@ -157,8 +193,7 @@ void ToolBar::update_button()
     unpack_buttons();
     pack_buttons();
 
-    if( m_buttonbar.get_children().size() ) show_toolbar();
-    else hide_toolbar();
+    if( ! m_buttonbar_shown ) close_buttonbar();
 
     // 進む、戻るボタンのsensitive状態を更新する
     set_url( m_url );
@@ -176,6 +211,18 @@ void ToolBar::unpack_buttons()
     }
 }
 
+// 検索ツールバー上のボタンのアンパック
+void ToolBar::unpack_search_buttons()
+{
+    if( ! m_searchbar ) return;
+
+    std::list< Gtk::Widget* > lists = m_searchbar->get_children();
+    std::list< Gtk::Widget* >::iterator it = lists.begin();
+    for( ; it != lists.end(); ++it ){
+        m_searchbar->remove( *(*it) );
+        if( dynamic_cast< Gtk::SeparatorToolItem* >( *it ) ) delete *it;
+    }
+}
 
 // ボタンのrelief指定
 void ToolBar::set_relief()
@@ -336,12 +383,9 @@ void ToolBar::open_searchbar()
     std::cout << "ToolBar::open_searchbar\n";
 #endif
 
-    if( ! m_searchbar_shown ){
-        pack_start( *m_searchbar, Gtk::PACK_SHRINK );
-        show_all_children();
-        m_searchbar_shown = true;
-        set_relief();
-    }
+    // フラグだけ立てて実際に pack するのは show_toolbar() の中
+    // 何故そんな面倒な事をしているかは show_toolbar() の説明を参照
+    m_searchbar_shown = true;
 }
 
 
@@ -354,10 +398,15 @@ void ToolBar::close_searchbar()
     std::cout << "ToolBar::close_searchbar\n";
 #endif
 
-    if( m_searchbar_shown ){
+    m_searchbar_shown = false;
+
+    if( m_searchbar_packed ){
+
         remove( *m_searchbar );
+
         show_all_children();
-        m_searchbar_shown = false;
+        m_searchbar_packed = false;
+
         m_admin->set_command( "focus_current_view" );
     }
 }
@@ -411,7 +460,7 @@ void ToolBar::slot_toggle_searchbar()
 //
 // 検索 entry
 //
-Gtk::ToolItem* ToolBar::get_entry_search( const int mode )
+Gtk::ToolItem* ToolBar::get_tool_search( const int mode )
 {
     if( ! m_tool_search ){
 
@@ -430,9 +479,15 @@ Gtk::ToolItem* ToolBar::get_entry_search( const int mode )
 }
 
 
-void ToolBar::add_search_mode( const int mode )
+SKELETON::CompletionEntry* ToolBar::get_entry_search()
 {
-    if( m_entry_search ) m_entry_search->add_mode( mode );
+    return m_entry_search;
+}
+
+
+void ToolBar::add_search_control_mode( const int mode )
+{
+    if( m_entry_search ) m_entry_search->add_control_mode( mode );
 }
 
 
@@ -472,7 +527,7 @@ void ToolBar::slot_active_search()
 }
 
 
-void ToolBar::slot_operate_search( int controlid )
+void ToolBar::slot_operate_search( const int controlid )
 {
     if( ! m_enable_slot ) return;
     if( m_url.empty() || ! m_admin ) return;
@@ -496,7 +551,7 @@ void ToolBar::focus_entry_search()
 //
 // 上検索
 //
-Gtk::ToolItem* ToolBar::get_button_up_search()
+Gtk::ToolButton* ToolBar::get_button_up_search()
 {
     if( ! m_button_up_search ){
         m_button_up_search = Gtk::manage( new ImgToolButton( Gtk::Stock::GO_UP ) );
@@ -525,7 +580,7 @@ void ToolBar::slot_clicked_up_search()
 //
 // 下検索
 //
-Gtk::ToolItem* ToolBar::get_button_down_search()
+Gtk::ToolButton* ToolBar::get_button_down_search()
 {
     if( ! m_button_down_search ){
         m_button_down_search = Gtk::manage( new ImgToolButton( Gtk::Stock::GO_DOWN ) );
@@ -723,7 +778,7 @@ void ToolBar::slot_clicked_stop()
 //
 // 閉じるボタン
 //
-Gtk::ToolItem* ToolBar::get_button_close()
+Gtk::ToolButton* ToolBar::get_button_close()
 {
     if( ! m_button_close ){
         m_button_close = Gtk::manage( new ImgToolButton( Gtk::Stock::CLOSE ) );
@@ -819,6 +874,36 @@ void ToolBar::slot_clicked_favorite()
 }
 
 
+//
+// UNDO ボタン
+//
+Gtk::ToolButton* ToolBar::get_button_undo()
+{
+    if( ! m_button_undo ){
+        m_button_undo = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::UNDO ) );
+        m_button_undo->set_sensitive( false );
+        set_tooltip( *m_button_undo, CONTROL::get_label_motions( CONTROL::Undo ) );
+    }
+
+    return m_button_undo;
+}
+
+
+//
+// REDO ボタン
+//
+Gtk::ToolButton* ToolBar::get_button_redo()
+{
+    if( ! m_button_redo ){
+        m_button_redo = Gtk::manage( new SKELETON::ImgToolButton( Gtk::Stock::REDO ) );
+        m_button_redo->set_sensitive( false );
+        set_tooltip( *m_button_redo, CONTROL::get_label_motions( CONTROL::Redo ) );
+    }
+
+    return m_button_redo;
+}
+
+
 //
 // 戻るボタン
 //
