@@ -4,19 +4,21 @@
 #define _TYPE_H
 
 #include <string>
-#include <list>
+#include <vector>
 
 enum 
 {
     // 板のタイプ
     TYPE_BOARD_2CH = 0,
     TYPE_BOARD_2CH_COMPATI,  // 2ch 互換
+    TYPE_BOARD_LOCAL,        // ローカルファイル
     TYPE_BOARD_JBBS,         // したらば
     TYPE_BOARD_MACHI,        // まち
     TYPE_BOARD_UNKNOWN,
 
     // その他一般的なデータタイプ
     TYPE_BOARD,
+    TYPE_BOARD_UPDATE,
     TYPE_THREAD,
     TYPE_THREAD_UPDATE,
     TYPE_THREAD_OLD,
@@ -30,6 +32,7 @@ enum
     TYPE_USRCMD,
     TYPE_LINKFILTER,
     TYPE_SEPARATOR,
+    TYPE_FILE,
 
     TYPE_UNKNOWN
 };
@@ -46,7 +49,7 @@ namespace CORE
         std::string data;
     };
 
-    typedef std::list< CORE::DATA_INFO > DATA_INFO_LIST;
+    typedef std::vector< CORE::DATA_INFO > DATA_INFO_LIST;
 }
 
 #endif
